import requests
import json
import time
import traceback

from ngwshare.utils.date_util import str2datetime
from ngwshare.utils.http_util import get_ua
import pandas as pd
import datetime


def get_T0TradeOrder(strategy_id=None, start=None, end=None):
    split_list = strategy_id.split('.')
    symbol = split_list[0]
    exchange = 'SHSE' if split_list[0] == 'SH' else 'SZSE'
    # url = 'https://testshq.niuguwang.com/aquote/quote/Tick.ashx?startTime={}&endTime={}&symbol={}&exchange={}&limit={}'\
    #     .format(start,end,symbol,exchange,limit)
    url = 'http://192.168.3.212:6667/t0/home/Tick.ashx?startTime={}&endTime={}&symbol={}&exchange={}&limit={}' \
        .format(start, end, symbol, exchange, limit)
    try:
        headers = {'User-Agent': get_ua()}
        response = requests.get(url, headers=headers).content.decode()
        response_json = json.loads(response)
        if response_json['error_no'] == 0:
            return pd.DataFrame(response_json['data'])
        else:
            return pd.DataFrame()
    except Exception:
        print(traceback.format_exc())


def GetHXL2Stock():
    try:
        url = "https://stq.niuguwang.com/zljl/GetStock"
        headers = {'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        try:
            response_json = json.loads(response.content.decode())
            # print(response_json)
            if response_json.get('resultCode') == 0:
                return response_json.get('data')
            else:
                return []
        except:
            return []


def GetHXL2Stock2():
    try:
        url = "https://teststq.niuguwang.com/technology/GetStock"
        headers = {'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        try:
            response_json = json.loads(response.content.decode())
            # print(response_json)
            if response_json.get('resultCode') == 0:
                return response_json.get('data')
            else:
                return []
        except:
            return []

def UpdateHXL2Stock(body=None):
    try:
        url = "https://stq.niuguwang.com/zljl/RefreshStock"
        headers = {"Content-Type": "application/json", 'User-Agent': get_ua()}
        response = requests.post(url, data=json.dumps(body), headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        try:
            response_json = json.loads(response.content.decode())
            # print(response_json)
            if response_json.get('resultCode') == 0:
                return response_json.get('data')
            else:
                return None
        except:
            return None

def UpdateHXL2Stock2(body=None):
    try:
        url = "https://teststq.niuguwang.com/technology/RefreshStock"
        headers = {"Content-Type": "application/json", 'User-Agent': get_ua()}
        response = requests.post(url, data=json.dumps(body), headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        try:
            response_json = json.loads(response.content.decode())
            # print(response_json)
            if response_json.get('resultCode') == 0:
                return response_json.get('data')
            else:
                return None
        except:
            return None





def GetT0Factor():
    try:
        url = "https://stq.niuguwang.com//zljl/factor"
        headers = {'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        try:
            response_json = json.loads(response.content.decode())
            # print(response_json)
            if response_json.get('resultCode') == 0:
                return response_json.get('data')
            else:
                return {}
        except:
            return {}


def AddT0Factor(body=None):
    try:
        url = "https://stq.niuguwang.com//zljl/addfactor"
        headers = {"Content-Type": "application/json", 'User-Agent': get_ua()}
        response = requests.post(url, data=json.dumps(body), headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        try:
            response_json = json.loads(response.content.decode())
            # print(response_json)
            if response_json.get('resultCode') == 0:
                return response_json.get('data')
            else:
                return None
        except:
            return None


if __name__ == '__main__':
    t1 = time.time()


    # start = '2021-07-16 09:30:00'
    # end = '2021-07-16 15:00:00'
    # data = get_T0TradeOrder(strategy_id=13, start=start, end=end)
    # print(data)

    # data = GetHXL2Stock()
    # print(data)
    # data = GetHXL2Stock2()
    # print(data)

    # stock_list = ['000651.SZ', '000995.SZ', '003040.SZ', '300144.SZ', '300339.SZ', '300397.SZ', '300598.SZ',
    #               '300722.SZ', '300727.SZ', '300981.SZ', '600519.SH', '601005.SH', '603000.SH', '600000.SH', '600436.SH']
    # data = UpdateHXL2Stock(stock_list)
    # print(data)

    # stock_list = ['000651.SZ', '000995.SZ', '003040.SZ', '300144.SZ', '300339.SZ', '300397.SZ', '300598.SZ', '300722.SZ',
    #               '300727.SZ', '300981.SZ', '300623.SZ', '600329.SH', '603976.SH', '600702.SH', '603126.SH', '603222.SH', '600753.SH', '600696.SH']
    # data = UpdateHXL2Stock2(stock_list)
    # print(data)





    data = GetT0Factor()
    print(data)


    factor = {
        '000651': {'SecuCode': '000651.SZ', 'Interval': 20, 'Intercept': 0.006735499387361307,
                         'alpha_2_0': -3.44054491897948e-05, 'alpha_2_1': 3.586306255880466e-06,
                         'alpha_2_2': 6.580464653564715e-06, 'alpha_2_3': 3.825379213485994e-06,
                         'alpha_2_4': 5.587124171267873e-06, 'alpha_2_5': 1.0968547951302185e-06,
                         'alpha_2_6': 1.6555657424923736e-06, 'alpha_2_7': 2.939855348497141e-07,
                         'alpha_2_8': 1.4645985988330723e-06, 'alpha_2_9': 1.8931485571489304e-06,
                         'alpha_2_10': -1.950808224683876e-06, 'alpha_2_11': 3.9259044766585305e-06,
                         'alpha_2_12': 3.2110273599128623e-06, 'alpha_2_13': 5.286058163296955e-06,
                         'alpha_2_14': 3.6876391719441897e-06, 'alpha_2_15': 5.276633175037808e-06,
                         'alpha_2_16': 4.157432610577657e-06, 'alpha_2_17': 3.407758430304364e-06,
                         'alpha_2_18': 4.054474629802949e-06, 'alpha_2_19': 9.160045332125962e-06,
                         'alpha_3_0': 3.426449833960794e-05, 'alpha_3_1': -3.4361121488527462e-06,
                         'alpha_3_2': -7.103615112224218e-06, 'alpha_3_3': -4.288091577790709e-06,
                         'alpha_3_4': -5.936408155939886e-06, 'alpha_3_5': -1.8286599707716513e-06,
                         'alpha_3_6': -1.934601196609543e-06, 'alpha_3_7': -6.776107362009545e-07,
                         'alpha_3_8': -1.717945356544383e-06, 'alpha_3_9': -1.9277689855613123e-06,
                         'alpha_3_10': 1.9303586707669125e-06, 'alpha_3_11': -3.6856885218907838e-06,
                         'alpha_3_12': -3.3269127166120544e-06, 'alpha_3_13': -5.003434091769085e-06,
                         'alpha_3_14': -3.2527799906481073e-06, 'alpha_3_15': -5.1589008449668576e-06,
                         'alpha_3_16': -3.900162439165763e-06, 'alpha_3_17': -3.2521113736512644e-06,
                         'alpha_3_18': -4.150874501744998e-06, 'alpha_3_19': -8.94039752754996e-06,
                         'alpha_spread_5_0': -0.10334107878606165, 'alpha_spread_5_1': -0.018147547047730642,
                         'alpha_spread_5_2': -0.0035835275942207104, 'alpha_spread_5_3': 0.0141616630031536,
                         'alpha_spread_5_4': -0.00010985972751892842, 'alpha_spread_5_5': 0.014648584870584364,
                         'alpha_spread_5_6': -0.026652343750396337, 'alpha_spread_5_7': 0.01505158662100341,
                         'alpha_spread_5_8': 0.009766990666175007, 'alpha_spread_5_9': -0.0025922544161480765,
                         'alpha_spread_6_0': 0.19275758066081314, 'alpha_spread_6_1': 0.05102090301842273,
                         'alpha_spread_6_2': 0.015312133422708901, 'alpha_spread_6_3': -0.07259783066058961,
                         'alpha_spread_6_4': 0.01049960275101303, 'alpha_spread_6_5': -0.01584302493467633,
                         'alpha_spread_6_6': 0.020571203340418544, 'alpha_spread_6_7': -0.011111930213535745,
                         'alpha_spread_6_8': -0.012655364406038516, 'alpha_spread_6_9': 0.0008518627659966345,
                         'alpha_ret_0': 0.7628640127592057, 'alpha_ret_1': 0.8074337672273111,
                         'alpha_ret_2': 0.566703080640379, 'alpha_ret_3': 0.36446611908350685,
                         'alpha_ret_4': 0.14666266429747743, 'alpha_ret_5': 0.05556512894634652,
                         'alpha_ret_6': -0.06939123227085843, 'alpha_ret_7': -0.2656851891998796,
                         'alpha_ret_8': -0.30965807617875973, 'alpha_ret_9': -0.32353427920065264,
                         'alpha_IF_0': 0.0017201338273264612, 'alpha_IF_1': 0.0018577896628799214,
                         'alpha_IF_2': 0.0016966954786898753, 'alpha_IF_3': -0.0003209835780964019,
                         'alpha_IF_4': -0.0005788393931889068, 'alpha_IF_5': -0.000931555504048253,
                         'alpha_IF_6': -0.0014915856348290232, 'alpha_IF_7': -0.0017149959082720758,
                         'alpha_IF_8': -0.0014733937956105437, 'alpha_IF_9': -0.0009565300701319953,
                         'alpha_IC_0': -0.0008491158249989434, 'alpha_IC_1': -0.0008588099534756872,
                         'alpha_IC_2': -0.0009688527235841507, 'alpha_IC_3': 0.00016857880575024982,
                         'alpha_IC_4': 0.0002321510980681497, 'alpha_IC_5': 0.00030827555633414216,
                         'alpha_IC_6': -0.00020781470549337584, 'alpha_IC_7': 0.00013668998381814442,
                         'alpha_IC_8': 0.0004116377106932629, 'alpha_IC_9': 7.592450364442568e-05,
                         'alpha_IH_0': -0.000885037022430167, 'alpha_IH_1': -0.0010805652187582157,
                         'alpha_IH_2': -0.000610570424164057, 'alpha_IH_3': 9.380600100949711e-05,
                         'alpha_IH_4': 0.00033759320911958804, 'alpha_IH_5': 0.0007582365165976246,
                         'alpha_IH_6': 0.0027027052412705497, 'alpha_IH_7': 0.002321956525805406,
                         'alpha_IH_8': 0.0013655646744425343, 'alpha_IH_9': 0.001286749833625518,
                         'ofi_0': 3.1454733987879702e-06, 'ofi_1': -2.2770792549513206e-06,
                         'ofi_2': -3.2372760432274113e-06, 'ofi_3': -3.6394394212327185e-06,
                         'ofi_4': -2.319608284546284e-06, 'ofi_5': -3.864337468851233e-06,
                         'ofi_6': -3.2923460809076446e-06, 'ofi_7': -2.2048982389448576e-06,
                         'ofi_8': -2.9620767554460777e-06, 'ofi_9': -3.1443958849476687e-06,
                         'askt_0': 3.757727102035909e-06, 'askt_1': 2.7061111613268564e-06,
                         'askt_2': 2.270246839505006e-06, 'askt_3': 4.121089772142138e-06,
                         'askt_4': 3.994310430203943e-06, 'askt_5': 4.189742636061829e-06,
                         'askt_6': 4.225141738624812e-06, 'askt_7': 4.063584471984453e-06,
                         'askt_8': 5.025219984011354e-06, 'askt_9': 3.885344524126529e-06,
                         'bidt_0': -1.533767620757647e-06, 'bidt_1': -2.0142817490564917e-06,
                         'bidt_2': -1.7438299283030295e-06, 'bidt_3': -1.4208586509020985e-06,
                         'bidt_4': -5.195571804424259e-07, 'bidt_5': -4.1186795141371485e-07,
                         'bidt_6': -6.186805344079845e-07, 'bidt_7': -5.835025517011828e-07,
                         'bidt_8': -1.5241722715667182e-06, 'bidt_9': -2.3106653370897106e-06},
              '000995': {'SecuCode': '000995.SZ', 'Interval': 20, 'Intercept': -0.04216134005004186,
                         'alpha_2_0': -5.4802678525106444e-05, 'alpha_2_1': -2.0716187237834435e-05,
                         'alpha_2_2': -1.4768129301055014e-05, 'alpha_2_3': -9.086456556844282e-06,
                         'alpha_2_4': -3.844064469279366e-06, 'alpha_2_5': -3.3838211009930013e-06,
                         'alpha_2_6': 1.0242979995492629e-06, 'alpha_2_7': 3.437061404918931e-06,
                         'alpha_2_8': 3.443610753393422e-06, 'alpha_2_9': 7.092682405698358e-06,
                         'alpha_2_10': 5.9595025133011155e-06, 'alpha_2_11': 7.52016561815847e-06,
                         'alpha_2_12': 6.922803973830079e-06, 'alpha_2_13': 8.14563973632227e-06,
                         'alpha_2_14': 7.678400950346073e-06, 'alpha_2_15': 8.152380468196839e-06,
                         'alpha_2_16': 9.251908552877203e-06, 'alpha_2_17': 1.0846344631956452e-05,
                         'alpha_2_18': 1.2818066305448304e-05, 'alpha_2_19': 1.8268022693190838e-05,
                         'alpha_3_0': 5.5120941002849346e-05, 'alpha_3_1': 2.059618712981455e-05,
                         'alpha_3_2': 1.4839003341256684e-05, 'alpha_3_3': 9.228301668690706e-06,
                         'alpha_3_4': 4.207599865132577e-06, 'alpha_3_5': 3.7691248682586937e-06,
                         'alpha_3_6': -4.088512067446316e-07, 'alpha_3_7': -2.8329220995409528e-06,
                         'alpha_3_8': -2.7795223165309294e-06, 'alpha_3_9': -6.575593294037874e-06,
                         'alpha_3_10': -5.404876508577811e-06, 'alpha_3_11': -7.082881666422967e-06,
                         'alpha_3_12': -6.482762832334565e-06, 'alpha_3_13': -7.72342395422471e-06,
                         'alpha_3_14': -7.275001513438404e-06, 'alpha_3_15': -7.810491570868757e-06,
                         'alpha_3_16': -8.70693632041495e-06, 'alpha_3_17': -1.0472820461048802e-05,
                         'alpha_3_18': -1.2245487958806757e-05, 'alpha_3_19': -1.752427701359356e-05,
                         'alpha_spread_5_0': -0.3108493808802386, 'alpha_spread_5_1': -0.0011784565019409916,
                         'alpha_spread_5_2': -0.0012535280446574718, 'alpha_spread_5_3': 0.0027088353748964374,
                         'alpha_spread_5_4': 9.399149743144361e-05, 'alpha_spread_5_5': 0.00116948383122383,
                         'alpha_spread_5_6': -0.00032010796611881367, 'alpha_spread_5_7': 0.003851800602221113,
                         'alpha_spread_5_8': 0.0035494820446690992, 'alpha_spread_5_9': -0.006236284503915362,
                         'alpha_spread_6_0': 0.4457889867079061, 'alpha_spread_6_1': -0.03318041649223676,
                         'alpha_spread_6_2': 0.007771356630896718, 'alpha_spread_6_3': 0.005580407500247227,
                         'alpha_spread_6_4': 0.11817361740009594, 'alpha_spread_6_5': -0.047716739230930824,
                         'alpha_spread_6_6': -0.0054309752755476535, 'alpha_spread_6_7': 0.03711162119349172,
                         'alpha_spread_6_8': 0.008215016026835434, 'alpha_spread_6_9': 0.052752780509636735,
                         'alpha_ret_0': 0.02466607323871866, 'alpha_ret_1': 0.022872914845195682,
                         'alpha_ret_2': -0.0024322923149132578, 'alpha_ret_3': -0.025316448478307732,
                         'alpha_ret_4': -0.004280998753971156, 'alpha_ret_5': -0.013362289407198571,
                         'alpha_ret_6': -0.004908204277960303, 'alpha_ret_7': -0.020710915664915692,
                         'alpha_ret_8': -0.031117655109252417, 'alpha_ret_9': -0.032262685009822475,
                         'alpha_IF_0': -0.00236543609937447, 'alpha_IF_1': -0.004850718256842348,
                         'alpha_IF_2': -0.005696466304736905, 'alpha_IF_3': -0.0060212757668967175,
                         'alpha_IF_4': -0.0062829521451477485, 'alpha_IF_5': -0.006220986501018124,
                         'alpha_IF_6': -0.005905435749144592, 'alpha_IF_7': -0.005442633590342285,
                         'alpha_IF_8': -0.004703990753001176, 'alpha_IF_9': -0.004074722901336069,
                         'alpha_IC_0': 0.0005124356623369083, 'alpha_IC_1': 0.001277178344282042,
                         'alpha_IC_2': 0.0014230288875622151, 'alpha_IC_3': 0.0014777167667173882,
                         'alpha_IC_4': 0.00155316513240937, 'alpha_IC_5': 0.0016548213331901232,
                         'alpha_IC_6': 0.0016521046236596148, 'alpha_IC_7': 0.0018206780177103916,
                         'alpha_IC_8': 0.0016637762689563772, 'alpha_IC_9': 0.0020044849841778702,
                         'alpha_IH_0': 0.002581128882562407, 'alpha_IH_1': 0.004664892145429352,
                         'alpha_IH_2': 0.005667949814562028, 'alpha_IH_3': 0.006056002413360708,
                         'alpha_IH_4': 0.006295259349099667, 'alpha_IH_5': 0.005981682885584359,
                         'alpha_IH_6': 0.005511663031308744, 'alpha_IH_7': 0.004454815041593409,
                         'alpha_IH_8': 0.003671256346091971, 'alpha_IH_9': 0.001965522337388477,
                         'ofi_0': 8.045822810132892e-07, 'ofi_1': 1.2766405477014273e-06,
                         'ofi_2': 4.336962511328694e-07, 'ofi_3': 9.309076760484801e-07,
                         'ofi_4': 1.0526827680330468e-06, 'ofi_5': 8.04926311697516e-07,
                         'ofi_6': 1.2829732844196838e-06, 'ofi_7': 8.647668662272056e-07,
                         'ofi_8': 1.1972721160590427e-06, 'ofi_9': 1.386703238534581e-06,
                         'askt_0': 1.6158183491885906e-06, 'askt_1': 1.349591196871529e-06,
                         'askt_2': 8.797706874630475e-07, 'askt_3': 6.694088473256553e-07,
                         'askt_4': 6.82594636938942e-07, 'askt_5': 1.132541680669269e-06,
                         'askt_6': 1.1163364675046212e-06, 'askt_7': 1.0144768636673906e-06,
                         'askt_8': 4.6540176411476287e-07, 'askt_9': 7.740801618620118e-07,
                         'bidt_0': -8.822760024062292e-07, 'bidt_1': -1.4701949707122354e-07,
                         'bidt_2': 2.143142132573118e-06, 'bidt_3': 6.6867722840955325e-06,
                         'bidt_4': 8.25239238807332e-06, 'bidt_5': 4.405766131683635e-06,
                         'bidt_6': 5.53788069923375e-06, 'bidt_7': 7.696236815670168e-06,
                         'bidt_8': 1.0607347810080946e-05, 'bidt_9': 1.1066216245570458e-05},
              '003040': {'SecuCode': '003040.SZ', 'Interval': 20, 'Intercept': 0.02101548864946245,
                         'alpha_2_0': -1.570633563269117e-05, 'alpha_2_1': 1.2340272619023311e-06,
                         'alpha_2_2': 7.351451262267619e-06, 'alpha_2_3': 8.70872393959494e-06,
                         'alpha_2_4': 6.287122947096674e-06, 'alpha_2_5': 5.035318708867976e-06,
                         'alpha_2_6': 4.623777890646769e-06, 'alpha_2_7': 4.894265149638549e-06,
                         'alpha_2_8': 1.0518705717013455e-06, 'alpha_2_9': 7.824970477630964e-07,
                         'alpha_2_10': -5.370505404703767e-07, 'alpha_2_11': 1.3559427887278793e-06,
                         'alpha_2_12': 2.9992729807516834e-08, 'alpha_2_13': -1.0625430739206118e-06,
                         'alpha_2_14': -8.436336685163088e-07, 'alpha_2_15': 6.074973608673437e-07,
                         'alpha_2_16': -4.1361941155077215e-08, 'alpha_2_17': 2.8710141831207513e-06,
                         'alpha_2_18': 4.564266705247916e-06, 'alpha_2_19': 4.118023491676675e-06,
                         'alpha_3_0': 1.5567653449516528e-05, 'alpha_3_1': -1.2010455685079298e-06,
                         'alpha_3_2': -7.168484236904304e-06, 'alpha_3_3': -8.625967373558162e-06,
                         'alpha_3_4': -6.231954936993402e-06, 'alpha_3_5': -5.1916364645509396e-06,
                         'alpha_3_6': -4.9999465101358045e-06, 'alpha_3_7': -4.878702842946568e-06,
                         'alpha_3_8': -1.3146195295878238e-06, 'alpha_3_9': -9.644676996838773e-07,
                         'alpha_3_10': 4.694001823046471e-07, 'alpha_3_11': -1.306872133515399e-06,
                         'alpha_3_12': -2.278838230619549e-07, 'alpha_3_13': 7.757029467765181e-07,
                         'alpha_3_14': 4.639976356381869e-07, 'alpha_3_15': -7.194847053754408e-07,
                         'alpha_3_16': -1.0340700882776263e-07, 'alpha_3_17': -2.8471775655833294e-06,
                         'alpha_3_18': -4.501513807448981e-06, 'alpha_3_19': -3.866897136427818e-06,
                         'alpha_spread_5_0': -0.42468453786870375, 'alpha_spread_5_1': 0.011689672199815536,
                         'alpha_spread_5_2': -0.015052084468444454, 'alpha_spread_5_3': 0.012745496018718048,
                         'alpha_spread_5_4': 0.007791670001412347, 'alpha_spread_5_5': -0.00500712684884409,
                         'alpha_spread_5_6': -0.0021586639059612794, 'alpha_spread_5_7': 0.00023420537232398254,
                         'alpha_spread_5_8': 0.0028189587763974115, 'alpha_spread_5_9': -0.010183219340801871,
                         'alpha_spread_6_0': 0.12425805150813085, 'alpha_spread_6_1': 0.011029432482286262,
                         'alpha_spread_6_2': 0.008528145921616973, 'alpha_spread_6_3': -0.0039806957603200676,
                         'alpha_spread_6_4': 0.009078421467931884, 'alpha_spread_6_5': -0.004086127863979966,
                         'alpha_spread_6_6': 0.0019401158696777812, 'alpha_spread_6_7': -0.0062777810192550885,
                         'alpha_spread_6_8': -0.0034487677534341316, 'alpha_spread_6_9': 0.0077450793007406505,
                         'alpha_ret_0': 0.42250446297894184, 'alpha_ret_1': 0.5438250565675828,
                         'alpha_ret_2': 0.4141198198595927, 'alpha_ret_3': 0.2773549544146578,
                         'alpha_ret_4': 0.09865734342035348, 'alpha_ret_5': 0.04275528947809094,
                         'alpha_ret_6': -0.01848899362742616, 'alpha_ret_7': -0.10980389594737971,
                         'alpha_ret_8': -0.09171106957612428, 'alpha_ret_9': -0.12388303887439846,
                         'alpha_IF_0': 0.0002604173635358964, 'alpha_IF_1': 0.0025455704730790833,
                         'alpha_IF_2': 0.0033578710600334046, 'alpha_IF_3': 0.003474256558458436,
                         'alpha_IF_4': 0.0030927655088121924, 'alpha_IF_5': 0.002873058217741776,
                         'alpha_IF_6': 0.002633512078787911, 'alpha_IF_7': 0.001959396480198775,
                         'alpha_IF_8': 0.0014249699735537904, 'alpha_IF_9': 0.0009854719148516824,
                         'alpha_IC_0': 0.00032134772650166805, 'alpha_IC_1': -0.0014327797722349593,
                         'alpha_IC_2': -0.0013873173569219994, 'alpha_IC_3': -0.0012611293222547992,
                         'alpha_IC_4': -0.001000478077790605, 'alpha_IC_5': -0.0007897752070762278,
                         'alpha_IC_6': -0.0007462969011951312, 'alpha_IC_7': -0.0005918345222629066,
                         'alpha_IC_8': -0.0004780356410938884, 'alpha_IC_9': -0.0003794412497707472,
                         'alpha_IH_0': -0.0012023945216890033, 'alpha_IH_1': -0.0008152925440868167,
                         'alpha_IH_2': -0.0021600447061749743, 'alpha_IH_3': -0.0025953119770005264,
                         'alpha_IH_4': -0.002572531527183986, 'alpha_IH_5': -0.0026945622420038087,
                         'alpha_IH_6': -0.0024258040906356302, 'alpha_IH_7': -0.001718679376671667,
                         'alpha_IH_8': -0.0011452413804576757, 'alpha_IH_9': -0.000696706120585181,
                         'ofi_0': 1.3492737636718354e-05, 'ofi_1': 4.3907891742524995e-07,
                         'ofi_2': -4.590476804991032e-06, 'ofi_3': -6.180645878408678e-06,
                         'ofi_4': -1.1304710569347807e-06, 'ofi_5': -2.016536238837594e-06,
                         'ofi_6': -7.474775657591683e-07, 'ofi_7': 4.1586426029874765e-09,
                         'ofi_8': -4.98951766019294e-06, 'ofi_9': -6.455782560454911e-06,
                         'askt_0': 1.4223422717030573e-05, 'askt_1': 7.518587396547808e-09,
                         'askt_2': 1.745013624645371e-07, 'askt_3': -6.583877573274389e-08,
                         'askt_4': -9.466192333539093e-08, 'askt_5': -9.248940738910095e-08,
                         'askt_6': -1.0685595187974901e-07, 'askt_7': -8.917332517844598e-08,
                         'askt_8': -7.26531957842294e-08, 'askt_9': -6.920277322212825e-08,
                         'bidt_0': 1.2921433815639687e-05, 'bidt_1': 7.238145163137567e-06,
                         'bidt_2': 8.785327594286304e-06, 'bidt_3': 1.3512262928857638e-05,
                         'bidt_4': 1.8170824320068548e-05, 'bidt_5': 2.3544105273757956e-05,
                         'bidt_6': 2.1480420859765513e-05, 'bidt_7': 1.741195524029444e-05,
                         'bidt_8': 9.356196738710216e-06, 'bidt_9': 7.355715869765217e-06},
              '300144': {'SecuCode': '300144.SZ', 'Interval': 20, 'Intercept': 0.0036994127625419775,
                         'alpha_2_0': -9.284393933272842e-06, 'alpha_2_1': 3.4702163771399564e-06,
                         'alpha_2_2': 4.209979853699356e-06, 'alpha_2_3': 4.010901824735359e-06,
                         'alpha_2_4': 4.499647897125911e-06, 'alpha_2_5': 3.7673684791535724e-06,
                         'alpha_2_6': 2.78174845693709e-06, 'alpha_2_7': 2.3469325375564372e-06,
                         'alpha_2_8': 1.9739974790726965e-06, 'alpha_2_9': 1.14336638803217e-06,
                         'alpha_2_10': -3.1711748677365984e-07, 'alpha_2_11': 7.579721917694943e-07,
                         'alpha_2_12': 3.2030010613164924e-07, 'alpha_2_13': 5.181268429783056e-07,
                         'alpha_2_14': 8.169448929702122e-07, 'alpha_2_15': 3.099321455645693e-07,
                         'alpha_2_16': -5.949734631127236e-07, 'alpha_2_17': -9.393431628713054e-07,
                         'alpha_2_18': -1.0663153816010604e-06, 'alpha_2_19': -2.0020040445394134e-06,
                         'alpha_3_0': 9.382923585071353e-06, 'alpha_3_1': -3.2221067404216584e-06,
                         'alpha_3_2': -3.981364243886114e-06, 'alpha_3_3': -3.861306960331832e-06,
                         'alpha_3_4': -4.439564049538504e-06, 'alpha_3_5': -3.686538609755233e-06,
                         'alpha_3_6': -2.767845859368535e-06, 'alpha_3_7': -2.407769569383197e-06,
                         'alpha_3_8': -2.1065874611689268e-06, 'alpha_3_9': -1.1744180122237832e-06,
                         'alpha_3_10': 2.0437540595245834e-07, 'alpha_3_11': -8.459842782455354e-07,
                         'alpha_3_12': -4.533569872784527e-07, 'alpha_3_13': -6.562655816805806e-07,
                         'alpha_3_14': -9.663429573694227e-07, 'alpha_3_15': -4.202456600016971e-07,
                         'alpha_3_16': 4.8677648858471e-07, 'alpha_3_17': 8.168953003321046e-07,
                         'alpha_3_18': 9.127124501251434e-07, 'alpha_3_19': 1.8397687407588423e-06,
                         'alpha_spread_5_0': -0.1585968120335, 'alpha_spread_5_1': 0.00685566491890083,
                         'alpha_spread_5_2': 0.004815832389176115, 'alpha_spread_5_3': 0.008402335174562842,
                         'alpha_spread_5_4': 0.0010141973776302611, 'alpha_spread_5_5': 0.0009847125086089562,
                         'alpha_spread_5_6': -0.006027036783896088, 'alpha_spread_5_7': -0.00121788315714848,
                         'alpha_spread_5_8': 0.0021764016252259818, 'alpha_spread_5_9': 0.010136547952805748,
                         'alpha_spread_6_0': 0.12644490034250477, 'alpha_spread_6_1': 0.00026517401068040986,
                         'alpha_spread_6_2': -0.00041318430152831716, 'alpha_spread_6_3': -0.030851531286577076,
                         'alpha_spread_6_4': -0.00910811948998561, 'alpha_spread_6_5': -0.013642532546563987,
                         'alpha_spread_6_6': 0.006097005804111875, 'alpha_spread_6_7': 0.0119219429151865,
                         'alpha_spread_6_8': 0.013691207726336033, 'alpha_spread_6_9': 0.015855272672179954,
                         'alpha_ret_0': -0.07668487559506132, 'alpha_ret_1': 0.0962644333647645,
                         'alpha_ret_2': 0.1162632191402279, 'alpha_ret_3': 0.07159816920121713,
                         'alpha_ret_4': 0.023446200567090764, 'alpha_ret_5': -0.01676709535899155,
                         'alpha_ret_6': -0.04858818589583496, 'alpha_ret_7': -0.06854992424861941,
                         'alpha_ret_8': -0.11249304115941859, 'alpha_ret_9': -0.1217116052449415,
                         'alpha_IF_0': -0.00015829116085723955, 'alpha_IF_1': -0.0006655503121843579,
                         'alpha_IF_2': -0.0007991287121725652, 'alpha_IF_3': -0.0009604212845640591,
                         'alpha_IF_4': -0.000879334827066531, 'alpha_IF_5': -0.0007829673794340205,
                         'alpha_IF_6': -0.0008587989573090098, 'alpha_IF_7': -0.0011069079765178903,
                         'alpha_IF_8': -0.001020381534693229, 'alpha_IF_9': -0.0004956533336561421,
                         'alpha_IC_0': -0.00012597392381124097, 'alpha_IC_1': 0.00010413454380197815,
                         'alpha_IC_2': 0.00022228310992083083, 'alpha_IC_3': 0.00047485533331194694,
                         'alpha_IC_4': 0.00039940219677622415, 'alpha_IC_5': 0.0003680780054488757,
                         'alpha_IC_6': 0.0004195915817934582, 'alpha_IC_7': 0.0003929558927814813,
                         'alpha_IC_8': 0.00029798242010408945, 'alpha_IC_9': 0.00019121320362265647,
                         'alpha_IH_0': 0.0004935081328973943, 'alpha_IH_1': 0.0007961770860050293,
                         'alpha_IH_2': 0.0007516612222964906, 'alpha_IH_3': 0.0004660178456085724,
                         'alpha_IH_4': 0.0005050060446409564, 'alpha_IH_5': 0.00042503400587966445,
                         'alpha_IH_6': 0.0004301272744298964, 'alpha_IH_7': 0.000867147686192483,
                         'alpha_IH_8': 0.0009347290130279394, 'alpha_IH_9': 0.00036257772715059727,
                         'ofi_0': 5.671202672625965e-07, 'ofi_1': 1.7179868419918745e-07,
                         'ofi_2': -7.106154759021486e-07, 'ofi_3': -6.561970570622586e-07,
                         'ofi_4': -5.56402988779255e-07, 'ofi_5': -9.105920430220133e-08,
                         'ofi_6': -1.4426498342675155e-07, 'ofi_7': -1.0654588209325317e-07,
                         'ofi_8': -3.437737062825549e-07, 'ofi_9': -6.024049069746219e-07,
                         'askt_0': 3.0841532283010954e-06, 'askt_1': 2.782027371823402e-06,
                         'askt_2': 2.0758396548358565e-06, 'askt_3': 1.6454571107719986e-06,
                         'askt_4': 1.6939507778265359e-06, 'askt_5': 2.265614296222141e-06,
                         'askt_6': 3.2825083904591173e-06, 'askt_7': 2.3507734487137394e-06,
                         'askt_8': 2.90570881079708e-06, 'askt_9': 3.126030122976945e-06,
                         'bidt_0': 1.4023461095882373e-06, 'bidt_1': 1.2257431365277125e-06,
                         'bidt_2': -1.3212172835863414e-07, 'bidt_3': -6.309583361054121e-09,
                         'bidt_4': 4.832952935145861e-07, 'bidt_5': 4.919866912271407e-07,
                         'bidt_6': -2.5730115476441866e-07, 'bidt_7': 4.3886559370143287e-07,
                         'bidt_8': 2.5603737388652735e-07, 'bidt_9': -1.8645237766687933e-07},
              '300339': {'SecuCode': '300339.SZ', 'Interval': 20, 'Intercept': -0.06833193297909915,
                         'alpha_2_0': -3.881476984396706e-05, 'alpha_2_1': 6.789182676672024e-07,
                         'alpha_2_2': 3.5767830792571303e-06, 'alpha_2_3': 4.729041127816029e-06,
                         'alpha_2_4': 1.6066673005419454e-06, 'alpha_2_5': 2.3672855539470707e-06,
                         'alpha_2_6': -6.631113806373787e-07, 'alpha_2_7': -3.09431195534857e-06,
                         'alpha_2_8': -5.298222397443436e-06, 'alpha_2_9': -2.4175691921740377e-06,
                         'alpha_2_10': -9.11929703498533e-06, 'alpha_2_11': 3.4677520296216028e-06,
                         'alpha_2_12': 2.7813296568096512e-06, 'alpha_2_13': 2.761253569138658e-06,
                         'alpha_2_14': 3.939226137433869e-06, 'alpha_2_15': 4.548454237582841e-06,
                         'alpha_2_16': 4.8777692239106375e-06, 'alpha_2_17': 6.2975298754155505e-06,
                         'alpha_2_18': 8.018700299916875e-06, 'alpha_2_19': 1.0024377801579327e-05,
                         'alpha_3_0': 3.891941498343726e-05, 'alpha_3_1': -8.90679159665678e-07,
                         'alpha_3_2': -3.535110435872555e-06, 'alpha_3_3': -4.881780693251157e-06,
                         'alpha_3_4': -1.5366405339657181e-06, 'alpha_3_5': -2.5526802539698214e-06,
                         'alpha_3_6': 7.915940911102641e-07, 'alpha_3_7': 3.1641294557097684e-06,
                         'alpha_3_8': 5.477444795046676e-06, 'alpha_3_9': 2.5376747411159855e-06,
                         'alpha_3_10': 9.312843607025219e-06, 'alpha_3_11': -3.1734408240820566e-06,
                         'alpha_3_12': -2.513071986371675e-06, 'alpha_3_13': -2.5929492186764585e-06,
                         'alpha_3_14': -3.549813474531035e-06, 'alpha_3_15': -3.9948836873609625e-06,
                         'alpha_3_16': -4.1422839538245195e-06, 'alpha_3_17': -5.725821404729745e-06,
                         'alpha_3_18': -7.1821180855190005e-06, 'alpha_3_19': -8.912603821653365e-06,
                         'alpha_spread_5_0': -0.2549304972935063, 'alpha_spread_5_1': -0.0022004948115712827,
                         'alpha_spread_5_2': 0.021856167021897716, 'alpha_spread_5_3': 0.0070886586753074535,
                         'alpha_spread_5_4': 0.018638933372739277, 'alpha_spread_5_5': 0.018962496186447093,
                         'alpha_spread_5_6': 0.020788386379410953, 'alpha_spread_5_7': 0.012073690353070288,
                         'alpha_spread_5_8': -0.0016959998192189075, 'alpha_spread_5_9': -0.01272268030893132,
                         'alpha_spread_6_0': 0.7799125207446105, 'alpha_spread_6_1': 0.034475843625222165,
                         'alpha_spread_6_2': -0.019436160700958556, 'alpha_spread_6_3': -0.005940240751445896,
                         'alpha_spread_6_4': -0.01643931941518357, 'alpha_spread_6_5': -0.0028655637057636934,
                         'alpha_spread_6_6': 0.00619546233308497, 'alpha_spread_6_7': -0.010342622630853707,
                         'alpha_spread_6_8': 0.006426712875569455, 'alpha_spread_6_9': 0.042408388591372276,
                         'alpha_ret_0': 1.150857515311572, 'alpha_ret_1': 1.3498126401971697,
                         'alpha_ret_2': 1.1473521936860842, 'alpha_ret_3': 0.6629377804039943,
                         'alpha_ret_4': 0.2269956573223472, 'alpha_ret_5': -0.16955403978132466,
                         'alpha_ret_6': -0.4747754777901108, 'alpha_ret_7': -0.7316815927656704,
                         'alpha_ret_8': -0.8192093666097123, 'alpha_ret_9': -0.665565927353942,
                         'alpha_IF_0': -0.00039093155155163793, 'alpha_IF_1': -0.002090848677046709,
                         'alpha_IF_2': -0.0014986769625092932, 'alpha_IF_3': -0.001449552994269388,
                         'alpha_IF_4': -0.0019812249242544934, 'alpha_IF_5': -0.0017573415489922858,
                         'alpha_IF_6': -0.0007468159146048477, 'alpha_IF_7': -4.352660158967772e-05,
                         'alpha_IF_8': 0.0010343803815868876, 'alpha_IF_9': 0.0008422752082890893,
                         'alpha_IC_0': -0.0006124728814680874, 'alpha_IC_1': 0.0002471755916037397,
                         'alpha_IC_2': 1.0509238978513621e-05, 'alpha_IC_3': -0.00022663060122141655,
                         'alpha_IC_4': 0.00020249343894384973, 'alpha_IC_5': 0.00031428429800478547,
                         'alpha_IC_6': 0.00035483150402045634, 'alpha_IC_7': 0.00022454395183220752,
                         'alpha_IC_8': -0.0002782929832745397, 'alpha_IC_9': -0.00022734744418509718,
                         'alpha_IH_0': 0.0018598775474117082, 'alpha_IH_1': 0.0026402952969096227,
                         'alpha_IH_2': 0.0022458562859876373, 'alpha_IH_3': 0.002698059809948534,
                         'alpha_IH_4': 0.0026074295525514626, 'alpha_IH_5': 0.002029206521002826,
                         'alpha_IH_6': 0.0004324050529963907, 'alpha_IH_7': -0.0003439171247286108,
                         'alpha_IH_8': -0.0009216935467527636, 'alpha_IH_9': -0.0007486459182529715,
                         'ofi_0': 5.7896187937377076e-06, 'ofi_1': 4.931029864809694e-06,
                         'ofi_2': 3.2381362033800867e-06, 'ofi_3': 2.5956827382826217e-06,
                         'ofi_4': 2.480154965622108e-06, 'ofi_5': 1.7219142246600495e-06,
                         'ofi_6': 1.9811393961049924e-06, 'ofi_7': 5.387217735418328e-07,
                         'ofi_8': -5.88263391779649e-07, 'ofi_9': -1.094092042224541e-06,
                         'askt_0': 1.1420424205924296e-06, 'askt_1': 8.575290659034134e-07,
                         'askt_2': 3.6172755187697e-07, 'askt_3': 9.643806260122564e-07,
                         'askt_4': 7.445017141965582e-07, 'askt_5': 1.0551039812823675e-06,
                         'askt_6': -2.0089921510945876e-08, 'askt_7': 4.0329300706621173e-07,
                         'askt_8': 4.957338485345238e-07, 'askt_9': 6.916083722257828e-07,
                         'bidt_0': 1.996005657193308e-06, 'bidt_1': 8.694605918372265e-07,
                         'bidt_2': 1.2271550408970825e-06, 'bidt_3': 1.8405393880597117e-06,
                         'bidt_4': 1.4081217125564262e-06, 'bidt_5': 1.3525180132186325e-06,
                         'bidt_6': 1.1060292141004265e-06, 'bidt_7': 9.900487841231067e-07,
                         'bidt_8': 1.0442540865387625e-06, 'bidt_9': 7.744161712291166e-07},
              '300397': {'SecuCode': '300397.SZ', 'Interval': 20, 'Intercept': -0.01782922234803712,
                         'alpha_2_0': -2.9143885701842992e-05, 'alpha_2_1': -5.545261871762317e-06,
                         'alpha_2_2': -9.190893130766148e-07, 'alpha_2_3': 6.944352681936395e-07,
                         'alpha_2_4': 1.5801674854092374e-06, 'alpha_2_5': 2.410007548071486e-06,
                         'alpha_2_6': 1.828424826407168e-06, 'alpha_2_7': 2.1637062994068488e-06,
                         'alpha_2_8': 2.453095943043215e-06, 'alpha_2_9': 2.48933404444397e-06,
                         'alpha_2_10': -8.934822213284577e-08, 'alpha_2_11': 2.8281364002517174e-06,
                         'alpha_2_12': 1.3625236829968392e-06, 'alpha_2_13': 2.1120326633567845e-06,
                         'alpha_2_14': 1.7616590468895884e-06, 'alpha_2_15': 1.9067298383523574e-06,
                         'alpha_2_16': 1.7788037486845778e-06, 'alpha_2_17': 1.088112235055423e-06,
                         'alpha_2_18': 9.90239573372957e-07, 'alpha_2_19': 2.0097040858970154e-06,
                         'alpha_3_0': 2.9016401755839695e-05, 'alpha_3_1': 5.639002913875941e-06,
                         'alpha_3_2': 1.0364957653749564e-06, 'alpha_3_3': -5.405197607023094e-07,
                         'alpha_3_4': -1.409474889790746e-06, 'alpha_3_5': -2.313339391731152e-06,
                         'alpha_3_6': -1.788617319988439e-06, 'alpha_3_7': -2.0258154784399766e-06,
                         'alpha_3_8': -2.359081063562841e-06, 'alpha_3_9': -2.4085522225511756e-06,
                         'alpha_3_10': 1.6770529342862695e-07, 'alpha_3_11': -2.781997585332411e-06,
                         'alpha_3_12': -1.5082724794985056e-06, 'alpha_3_13': -2.147454536031046e-06,
                         'alpha_3_14': -1.8394057493563422e-06, 'alpha_3_15': -1.8957010527460803e-06,
                         'alpha_3_16': -1.7625931053833484e-06, 'alpha_3_17': -1.1402907817687203e-06,
                         'alpha_3_18': -9.141003208322764e-07, 'alpha_3_19': -1.9730950300431497e-06,
                         'alpha_spread_5_0': -0.07912933683236834, 'alpha_spread_5_1': -0.012161896582944422,
                         'alpha_spread_5_2': 0.00614956295732931, 'alpha_spread_5_3': -0.0024425464230059496,
                         'alpha_spread_5_4': -0.0006556997949424885, 'alpha_spread_5_5': -0.0021348258819497545,
                         'alpha_spread_5_6': 0.006012556357198361, 'alpha_spread_5_7': -0.005182094369891305,
                         'alpha_spread_5_8': -0.0012974851268629437, 'alpha_spread_5_9': 0.013214531728798162,
                         'alpha_spread_6_0': 0.28508259462908025, 'alpha_spread_6_1': 0.04266403687649368,
                         'alpha_spread_6_2': -0.022215233944658085, 'alpha_spread_6_3': -0.003390291072108162,
                         'alpha_spread_6_4': 0.01830906474450677, 'alpha_spread_6_5': -0.0172949189084001,
                         'alpha_spread_6_6': -0.0067109500405404384, 'alpha_spread_6_7': 0.012288599265133367,
                         'alpha_spread_6_8': -0.010820295377503522, 'alpha_spread_6_9': 0.021180530588599214,
                         'alpha_ret_0': 0.6018101854676562, 'alpha_ret_1': 0.808961713068661,
                         'alpha_ret_2': 0.7748732554516493, 'alpha_ret_3': 0.6008527051063007,
                         'alpha_ret_4': 0.43159387678523714, 'alpha_ret_5': 0.2644738930997541,
                         'alpha_ret_6': 0.1511071242287473, 'alpha_ret_7': 0.03941473599471323,
                         'alpha_ret_8': -0.07247372744454376, 'alpha_ret_9': -0.12337859571760208,
                         'alpha_IF_0': 0.00039871827574718924, 'alpha_IF_1': 0.0005095571349977624,
                         'alpha_IF_2': 0.000924120284009839, 'alpha_IF_3': 0.0012087958339269927,
                         'alpha_IF_4': 0.0012057402670131235, 'alpha_IF_5': 0.0012793402648305133,
                         'alpha_IF_6': 0.0014816173096269837, 'alpha_IF_7': 0.0015100548644021244,
                         'alpha_IF_8': 0.0011076618570004275, 'alpha_IF_9': 0.000982529190564341,
                         'alpha_IC_0': -0.0007481725461273341, 'alpha_IC_1': -0.0006541427148119431,
                         'alpha_IC_2': -0.0005956902685016589, 'alpha_IC_3': -0.0005708659123431106,
                         'alpha_IC_4': -0.0005752589271732696, 'alpha_IC_5': -0.00037832559821716514,
                         'alpha_IC_6': -0.00023069217954814993, 'alpha_IC_7': -0.0002791447553359895,
                         'alpha_IC_8': 9.906179593904699e-05, 'alpha_IC_9': -3.0661891366972885e-05,
                         'alpha_IH_0': 0.0009478861549517054, 'alpha_IH_1': 0.0005969713258871848,
                         'alpha_IH_2': -0.00015351137059080953, 'alpha_IH_3': -0.0006354207086031924,
                         'alpha_IH_4': -0.000624257964833848, 'alpha_IH_5': -0.001143453096442856,
                         'alpha_IH_6': -0.0017672974434741883, 'alpha_IH_7': -0.00171450546583057,
                         'alpha_IH_8': -0.0018989640146928942, 'alpha_IH_9': -0.0014232886191741575,
                         'ofi_0': 3.674733607003066e-07, 'ofi_1': -3.9401625790544477e-07,
                         'ofi_2': -1.4583555619192033e-06, 'ofi_3': -6.945016417814459e-07,
                         'ofi_4': -7.917472194503251e-07, 'ofi_5': -7.521419642051364e-07,
                         'ofi_6': -1.912065957894524e-07, 'ofi_7': 1.6009580378221868e-07,
                         'ofi_8': 1.5434587007006818e-07, 'ofi_9': 7.294069613698235e-07,
                         'askt_0': 3.3645591819186784e-06, 'askt_1': 4.045516513725169e-06,
                         'askt_2': 6.6433247289563835e-06, 'askt_3': 5.412329173114714e-06,
                         'askt_4': 4.645579976001116e-06, 'askt_5': 6.629758660866823e-06,
                         'askt_6': 5.973773421108666e-06, 'askt_7': 6.04077462037324e-06,
                         'askt_8': 5.709900180594645e-06, 'askt_9': 5.022358973591326e-06,
                         'bidt_0': 4.3951080746555256e-07, 'bidt_1': -4.830210946192966e-07,
                         'bidt_2': -2.616299716531332e-07, 'bidt_3': 1.5669237828230784e-08,
                         'bidt_4': 3.2967970332567957e-07, 'bidt_5': -2.9675645686240323e-07,
                         'bidt_6': -1.1131016332817084e-06, 'bidt_7': -1.6701864457289379e-06,
                         'bidt_8': -1.524527543394908e-06, 'bidt_9': -1.3704860946957563e-06},
              '300598': {'SecuCode': '300598.SZ', 'Interval': 20, 'Intercept': 0.006496977261123994,
                         'alpha_2_0': -4.914080670434981e-05, 'alpha_2_1': 1.335951596789836e-05,
                         'alpha_2_2': 1.6706062381484583e-05, 'alpha_2_3': 8.82095587623877e-06,
                         'alpha_2_4': 5.877453954105646e-06, 'alpha_2_5': 1.0216915601465797e-05,
                         'alpha_2_6': 4.708762527727366e-06, 'alpha_2_7': -9.950146942469283e-07,
                         'alpha_2_8': 7.710800448534047e-06, 'alpha_2_9': 4.891134304810517e-06,
                         'alpha_2_10': -1.6172988831652896e-07, 'alpha_2_11': 7.389728480033649e-06,
                         'alpha_2_12': 1.140237385953563e-05, 'alpha_2_13': 1.601186945762995e-05,
                         'alpha_2_14': 1.306250455319268e-05, 'alpha_2_15': 1.41233709116206e-05,
                         'alpha_2_16': 1.1788097755395297e-05, 'alpha_2_17': 8.381728230562956e-06,
                         'alpha_2_18': 8.520669384446515e-06, 'alpha_2_19': 1.673577958920238e-05,
                         'alpha_3_0': 5.026026354967082e-05, 'alpha_3_1': -1.3312725305132227e-05,
                         'alpha_3_2': -1.6503362987718047e-05, 'alpha_3_3': -8.899906148357801e-06,
                         'alpha_3_4': -6.3504583420767525e-06, 'alpha_3_5': -1.0361815505269716e-05,
                         'alpha_3_6': -4.83816609283885e-06, 'alpha_3_7': 3.7178098442910354e-07,
                         'alpha_3_8': -8.052336161642226e-06, 'alpha_3_9': -5.663411794761776e-06,
                         'alpha_3_10': -1.5226106457087867e-07, 'alpha_3_11': -7.506061640196251e-06,
                         'alpha_3_12': -1.1207043125958692e-05, 'alpha_3_13': -1.5524482552826527e-05,
                         'alpha_3_14': -1.328094703076549e-05, 'alpha_3_15': -1.3955482502598657e-05,
                         'alpha_3_16': -1.1446641920448088e-05, 'alpha_3_17': -8.26471575730539e-06,
                         'alpha_3_18': -7.926733562639647e-06, 'alpha_3_19': -1.633027404362164e-05,
                         'alpha_spread_5_0': -0.39360012648413495, 'alpha_spread_5_1': -0.013976149687452494,
                         'alpha_spread_5_2': 0.0031004002666208076, 'alpha_spread_5_3': 0.006335533972256845,
                         'alpha_spread_5_4': 0.008916840456749103, 'alpha_spread_5_5': 0.007035437672571849,
                         'alpha_spread_5_6': 0.0010947251471108911, 'alpha_spread_5_7': -0.0004065985373811186,
                         'alpha_spread_5_8': -0.008374969357928403, 'alpha_spread_5_9': 0.000582293439238698,
                         'alpha_spread_6_0': 0.3277603603397909, 'alpha_spread_6_1': 0.006090841472172681,
                         'alpha_spread_6_2': -0.0399312083125606, 'alpha_spread_6_3': 0.0391386448941469,
                         'alpha_spread_6_4': -0.040548460045293784, 'alpha_spread_6_5': -0.042551816230691826,
                         'alpha_spread_6_6': 0.02009289173779672, 'alpha_spread_6_7': -0.03291959026057849,
                         'alpha_spread_6_8': 0.0018646504428423629, 'alpha_spread_6_9': -0.02192995492537676,
                         'alpha_ret_0': 0.6211174236976573, 'alpha_ret_1': 0.7761753183924351,
                         'alpha_ret_2': 0.7660812340971557, 'alpha_ret_3': 0.6260067453613404,
                         'alpha_ret_4': 0.36870656036725646, 'alpha_ret_5': 0.15975532141780735,
                         'alpha_ret_6': -0.014468329254497325, 'alpha_ret_7': -0.1669927341296015,
                         'alpha_ret_8': -0.26830397539611595, 'alpha_ret_9': -0.2903622050000896,
                         'alpha_IF_0': 0.00039630074015580685, 'alpha_IF_1': -0.0005829831652829365,
                         'alpha_IF_2': -0.0005812392247251388, 'alpha_IF_3': -0.0003409965600880611,
                         'alpha_IF_4': 0.0009148031783150026, 'alpha_IF_5': -2.1765161140249187e-05,
                         'alpha_IF_6': 0.001426974249923651, 'alpha_IF_7': 0.0010511629741075826,
                         'alpha_IF_8': 0.001750941187667506, 'alpha_IF_9': 0.0016373887867948908,
                         'alpha_IC_0': -0.0009224668430389276, 'alpha_IC_1': -0.0006253756980104289,
                         'alpha_IC_2': -0.0002423027222532912, 'alpha_IC_3': -0.0012260149703185136,
                         'alpha_IC_4': -0.0031616405218910792, 'alpha_IC_5': -0.0017178442097694384,
                         'alpha_IC_6': -0.003200703081825389, 'alpha_IC_7': -0.0024300849899837615,
                         'alpha_IC_8': -0.0025717666247471733, 'alpha_IC_9': -0.0022881737790337543,
                         'alpha_IH_0': 0.0011404489183816644, 'alpha_IH_1': 0.0020712996721649808,
                         'alpha_IH_2': 0.001282549516539189, 'alpha_IH_3': 0.003018078088856152,
                         'alpha_IH_4': 0.005274266567377652, 'alpha_IH_5': 0.003681611739379822,
                         'alpha_IH_6': 0.004650504017834614, 'alpha_IH_7': 0.0035957572702689884,
                         'alpha_IH_8': 0.002831061343034691, 'alpha_IH_9': 0.00241600937578904,
                         'ofi_0': -3.7580470658684834e-06, 'ofi_1': 3.3501873368018504e-06,
                         'ofi_2': 1.4709127341459345e-06, 'ofi_3': -6.329484432958249e-06,
                         'ofi_4': -2.3900457113041038e-05, 'ofi_5': -2.5329670796841285e-05,
                         'ofi_6': -2.7713329278153294e-05, 'ofi_7': -3.444327424361639e-05,
                         'ofi_8': -5.076545974139577e-05, 'ofi_9': -3.911994294444896e-05,
                         'askt_0': 7.771074906139928e-05, 'askt_1': 6.70343290800929e-05,
                         'askt_2': 7.986043024199978e-05, 'askt_3': 9.086881859244306e-05,
                         'askt_4': 0.0001079506991390543, 'askt_5': 0.00011200440530466786,
                         'askt_6': 0.00010933689318722172, 'askt_7': 9.197340909853194e-05,
                         'askt_8': 9.850547861001846e-05, 'askt_9': 0.00012232570480916053,
                         'bidt_0': -1.3025747692530548e-05, 'bidt_1': -5.586142005904099e-06,
                         'bidt_2': -1.5380199891417615e-05, 'bidt_3': -3.847294922467684e-05,
                         'bidt_4': -3.233703656422766e-05, 'bidt_5': -3.341540185703417e-05,
                         'bidt_6': -2.9113916676834836e-05, 'bidt_7': -4.67953309514173e-05,
                         'bidt_8': -2.5501996996427367e-05, 'bidt_9': -2.210198780244234e-05},
              '300722': {'SecuCode': '300722.SZ', 'Interval': 20, 'Intercept': -0.032131954722591054,
                         'alpha_2_0': -4.433606534712352e-05, 'alpha_2_1': 5.0291059224963045e-06,
                         'alpha_2_2': 9.0878871949625e-06, 'alpha_2_3': 1.0840311656332844e-05,
                         'alpha_2_4': 1.5230397507933252e-05, 'alpha_2_5': 1.5043086962081668e-05,
                         'alpha_2_6': 1.620267882549312e-05, 'alpha_2_7': 1.3588991082937252e-05,
                         'alpha_2_8': 1.5869535081922672e-05, 'alpha_2_9': 1.4147842466243106e-05,
                         'alpha_2_10': 9.026397456969182e-06, 'alpha_2_11': 1.3177930323279725e-05,
                         'alpha_2_12': 7.929071969922111e-06, 'alpha_2_13': 1.001365154746836e-05,
                         'alpha_2_14': 5.809232294205541e-06, 'alpha_2_15': 7.597519493449178e-06,
                         'alpha_2_16': 7.995257149486904e-06, 'alpha_2_17': 1.5884791435036667e-06,
                         'alpha_2_18': 1.2536756821461688e-05, 'alpha_2_19': 1.4638052629396902e-05,
                         'alpha_3_0': 4.6605882354275946e-05, 'alpha_3_1': -3.71894830081916e-06,
                         'alpha_3_2': -8.23386099539346e-06, 'alpha_3_3': -1.0330158201870672e-05,
                         'alpha_3_4': -1.4833776557807604e-05, 'alpha_3_5': -1.4795495299560887e-05,
                         'alpha_3_6': -1.5807867305879567e-05, 'alpha_3_7': -1.3299033195251404e-05,
                         'alpha_3_8': -1.5078580472102804e-05, 'alpha_3_9': -1.359859405369956e-05,
                         'alpha_3_10': -9.0065958888189e-06, 'alpha_3_11': -1.3118857482951444e-05,
                         'alpha_3_12': -8.038026143375596e-06, 'alpha_3_13': -9.785366295374012e-06,
                         'alpha_3_14': -5.643329356257574e-06, 'alpha_3_15': -7.390132195923842e-06,
                         'alpha_3_16': -7.939808539100421e-06, 'alpha_3_17': -1.8872357251642753e-06,
                         'alpha_3_18': -1.268176392820464e-05, 'alpha_3_19': -1.4869677391956244e-05,
                         'alpha_spread_5_0': -0.2927885163216427, 'alpha_spread_5_1': -0.008351542755022088,
                         'alpha_spread_5_2': 0.015073559886355024, 'alpha_spread_5_3': 0.0047666769230321916,
                         'alpha_spread_5_4': 0.008710652254118219, 'alpha_spread_5_5': -0.006137473442821455,
                         'alpha_spread_5_6': -0.00023482661952891362, 'alpha_spread_5_7': -0.006032660384212337,
                         'alpha_spread_5_8': -0.00036317722124811283, 'alpha_spread_5_9': 0.001159892283099241,
                         'alpha_spread_6_0': 0.45260569298704206, 'alpha_spread_6_1': 0.040634977714847954,
                         'alpha_spread_6_2': -0.0023268505296871896, 'alpha_spread_6_3': -0.028844486063633077,
                         'alpha_spread_6_4': -0.019391100445120324, 'alpha_spread_6_5': -0.008407148092054239,
                         'alpha_spread_6_6': -0.010393592743420402, 'alpha_spread_6_7': 0.00989273346432571,
                         'alpha_spread_6_8': -0.009610313049998319, 'alpha_spread_6_9': 0.03873636471535843,
                         'alpha_ret_0': 0.5477243411081734, 'alpha_ret_1': 0.6412331217429731,
                         'alpha_ret_2': 0.5928908622671902, 'alpha_ret_3': 0.4388713234430134,
                         'alpha_ret_4': 0.24259426048874422, 'alpha_ret_5': 0.09654410719430699,
                         'alpha_ret_6': -0.0282897746248805, 'alpha_ret_7': -0.10093470296835527,
                         'alpha_ret_8': -0.1448374830144988, 'alpha_ret_9': -0.13258237584739255,
                         'alpha_IF_0': 0.0007651629198654317, 'alpha_IF_1': 0.0022130145619392886,
                         'alpha_IF_2': 0.0001936903779929871, 'alpha_IF_3': -1.8321807153439612e-05,
                         'alpha_IF_4': -0.00042577818575879, 'alpha_IF_5': -0.000156005677356201,
                         'alpha_IF_6': 0.0010610499761091643, 'alpha_IF_7': 0.0013661957526535401,
                         'alpha_IF_8': 0.001203890031040159, 'alpha_IF_9': 0.0026715563678653075,
                         'alpha_IC_0': -0.0011439456926172098, 'alpha_IC_1': -0.003596583297434819,
                         'alpha_IC_2': -0.00245944541734139, 'alpha_IC_3': -0.0016799584582977687,
                         'alpha_IC_4': -0.00039724955563872277, 'alpha_IC_5': -9.645359641823234e-05,
                         'alpha_IC_6': 0.0004196552427555597, 'alpha_IC_7': 0.0003560822364171382,
                         'alpha_IC_8': 0.000674037502421516, 'alpha_IC_9': 0.00010116240622876588,
                         'alpha_IH_0': 0.0013282126559160912, 'alpha_IH_1': 0.004313715881319145,
                         'alpha_IH_2': 0.004991562828210264, 'alpha_IH_3': 0.003664231204998222,
                         'alpha_IH_4': 0.001579117502109933, 'alpha_IH_5': 0.0004999701401768957,
                         'alpha_IH_6': -0.002473518904243888, 'alpha_IH_7': -0.002822509966250305,
                         'alpha_IH_8': -0.003250353652191362, 'alpha_IH_9': -0.004297504455985724,
                         'ofi_0': 2.4230437564292823e-05, 'ofi_1': 2.8179177034496006e-05,
                         'ofi_2': 2.3128972278101887e-05, 'ofi_3': 2.579732494223937e-05,
                         'ofi_4': 2.798816850263521e-05, 'ofi_5': 3.121545347853917e-05,
                         'ofi_6': 3.0931421910687627e-05, 'ofi_7': 3.464212584547443e-05,
                         'ofi_8': 3.542442772155077e-05, 'ofi_9': 3.337728293849128e-05,
                         'askt_0': 1.4357952376550805e-05, 'askt_1': 4.74602945215475e-06,
                         'askt_2': 9.509914460953063e-06, 'askt_3': 5.851526919856384e-06,
                         'askt_4': 9.600802283056611e-07, 'askt_5': 3.691766263387951e-06,
                         'askt_6': 1.1838933673194586e-05, 'askt_7': 1.112641729293359e-05,
                         'askt_8': 3.449089174838545e-06, 'askt_9': 4.768584286405749e-06,
                         'bidt_0': -6.153742665225621e-06, 'bidt_1': -1.4918214714587464e-06,
                         'bidt_2': -9.836902665180738e-06, 'bidt_3': 8.381034299345851e-06,
                         'bidt_4': 4.932562297584807e-06, 'bidt_5': 1.5412384363586658e-05,
                         'bidt_6': 1.0667555550506402e-05, 'bidt_7': -2.9475788028883456e-06,
                         'bidt_8': 2.1367789563941345e-05, 'bidt_9': 1.3803770845195776e-05},
              '300727': {'SecuCode': '300727.SZ', 'Interval': 20, 'Intercept': -0.021114437683390868,
                         'alpha_2_0': -5.6368385058879394e-05, 'alpha_2_1': -3.622546320801705e-06,
                         'alpha_2_2': 4.833189050279689e-06, 'alpha_2_3': 7.184633170424298e-06,
                         'alpha_2_4': 6.0958180209057695e-06, 'alpha_2_5': 4.64844245070783e-06,
                         'alpha_2_6': 6.228978705465846e-06, 'alpha_2_7': 5.346839641273401e-06,
                         'alpha_2_8': 4.9324732447460214e-06, 'alpha_2_9': 1.5321238511839988e-06,
                         'alpha_2_10': -3.0586735874807666e-06, 'alpha_2_11': 3.934501171286488e-06,
                         'alpha_2_12': 3.6304149092004565e-06, 'alpha_2_13': 2.8710542568447388e-06,
                         'alpha_2_14': 6.061228610680416e-06, 'alpha_2_15': 3.1664939986016176e-06,
                         'alpha_2_16': 6.113416361988112e-06, 'alpha_2_17': 5.612177003025226e-06,
                         'alpha_2_18': 7.79397968253392e-06, 'alpha_2_19': 9.512419694173356e-06,
                         'alpha_3_0': 5.6902431725280496e-05, 'alpha_3_1': 3.4622811551082375e-06,
                         'alpha_3_2': -5.433810083193672e-06, 'alpha_3_3': -7.253904276693148e-06,
                         'alpha_3_4': -6.430235252691485e-06, 'alpha_3_5': -5.182191544571252e-06,
                         'alpha_3_6': -6.205629135516437e-06, 'alpha_3_7': -5.242197874661224e-06,
                         'alpha_3_8': -4.688847553431076e-06, 'alpha_3_9': -1.7618179162831368e-06,
                         'alpha_3_10': 3.0741962295769683e-06, 'alpha_3_11': -4.063036422458536e-06,
                         'alpha_3_12': -3.6250495333478244e-06, 'alpha_3_13': -2.45041276832045e-06,
                         'alpha_3_14': -5.528443091135155e-06, 'alpha_3_15': -3.1615539076924428e-06,
                         'alpha_3_16': -6.060347806135715e-06, 'alpha_3_17': -5.394725873334991e-06,
                         'alpha_3_18': -7.641009705712347e-06, 'alpha_3_19': -9.222199347684507e-06,
                         'alpha_spread_5_0': -0.6529828472814637, 'alpha_spread_5_1': -0.06624675906048948,
                         'alpha_spread_5_2': -0.009596694076505333, 'alpha_spread_5_3': 0.02247926613173373,
                         'alpha_spread_5_4': 0.06846619045559042, 'alpha_spread_5_5': 0.06902145232150458,
                         'alpha_spread_5_6': 0.007616246303820227, 'alpha_spread_5_7': 0.0024247420954479804,
                         'alpha_spread_5_8': 0.016014301583168286, 'alpha_spread_5_9': 0.0006775666974582871,
                         'alpha_spread_6_0': 0.709940117074379, 'alpha_spread_6_1': 0.08874574447056588,
                         'alpha_spread_6_2': -0.005007841655100266, 'alpha_spread_6_3': 0.007313266504613615,
                         'alpha_spread_6_4': -0.03903215757363806, 'alpha_spread_6_5': -0.05740959870873853,
                         'alpha_spread_6_6': -0.021728444676682845, 'alpha_spread_6_7': -0.001870678568516011,
                         'alpha_spread_6_8': -0.029106263869248805, 'alpha_spread_6_9': 0.004094530682005566,
                         'alpha_ret_0': 1.1945268958638928, 'alpha_ret_1': 1.4251208114303966,
                         'alpha_ret_2': 1.4385319876872376, 'alpha_ret_3': 1.145839646675031,
                         'alpha_ret_4': 0.7832314435099603, 'alpha_ret_5': 0.4510829341876197,
                         'alpha_ret_6': 0.1949778623029632, 'alpha_ret_7': -0.05556624498200186,
                         'alpha_ret_8': -0.16646033577954472, 'alpha_ret_9': -0.2389781862854107,
                         'alpha_IF_0': -0.001747801749395323, 'alpha_IF_1': -0.0018761590742545707,
                         'alpha_IF_2': -0.0014984204607576038, 'alpha_IF_3': 0.00031882656645141976,
                         'alpha_IF_4': 0.002046564632321742, 'alpha_IF_5': 0.003061734526905868,
                         'alpha_IF_6': 0.0036339786680655833, 'alpha_IF_7': 0.004019713403363135,
                         'alpha_IF_8': 0.0030131041771185012, 'alpha_IF_9': 0.0019940054546468385,
                         'alpha_IC_0': 0.00039071887523363326, 'alpha_IC_1': 0.00010171326303850574,
                         'alpha_IC_2': -0.0005552239496210299, 'alpha_IC_3': -0.001646500067597043,
                         'alpha_IC_4': -0.0016627440460965724, 'alpha_IC_5': -0.0005483173168718374,
                         'alpha_IC_6': -1.2848746632816138e-05, 'alpha_IC_7': 0.0001021882516334381,
                         'alpha_IC_8': 0.00074103700386659, 'alpha_IC_9': 0.0012498535771286704,
                         'alpha_IH_0': 0.0017447977565299168, 'alpha_IH_1': 0.002493339175125878,
                         'alpha_IH_2': 0.0033168256173842243, 'alpha_IH_3': 0.0028843038800020456,
                         'alpha_IH_4': 0.0003181467490912027, 'alpha_IH_5': -0.0035243795568188465,
                         'alpha_IH_6': -0.005536656899764227, 'alpha_IH_7': -0.0063665741431985605,
                         'alpha_IH_8': -0.006165311170520667, 'alpha_IH_9': -0.005695807148155451,
                         'ofi_0': -5.227206524502954e-06, 'ofi_1': -2.090122233153408e-06,
                         'ofi_2': 1.3738581875634779e-07, 'ofi_3': 5.054501877251743e-06,
                         'ofi_4': 4.391277130069429e-06, 'ofi_5': 9.768061649710682e-06,
                         'ofi_6': 1.4164176273253774e-05, 'ofi_7': 1.551545233168068e-05,
                         'ofi_8': 1.4668361016676613e-05, 'ofi_9': 9.47880841428447e-06,
                         'askt_0': 2.838044351397789e-05, 'askt_1': 2.3462663249342068e-05,
                         'askt_2': 1.5992921760526524e-05, 'askt_3': 1.0199484678695502e-05,
                         'askt_4': 1.8520563155337656e-05, 'askt_5': 1.3136528178488872e-05,
                         'askt_6': 1.1267147813207592e-05, 'askt_7': 1.2221996536446233e-05,
                         'askt_8': 1.3820032897727943e-05, 'askt_9': 1.4717372340935224e-05,
                         'bidt_0': 2.022144986759997e-05, 'bidt_1': 2.09894562777807e-05,
                         'bidt_2': 1.0986931936236594e-05, 'bidt_3': 1.8139016690782457e-05,
                         'bidt_4': 1.5140085733257564e-05, 'bidt_5': 1.2858194130709947e-05,
                         'bidt_6': 1.7357704641621358e-05, 'bidt_7': 8.636358165296653e-06,
                         'bidt_8': 1.322520327317597e-05, 'bidt_9': 1.096745173161558e-05},
              '300981': {'SecuCode': '300981.SZ', 'Interval': 20, 'Intercept': 0.0033360256046459525,
                         'alpha_2_0': -6.55244516439452e-05, 'alpha_2_1': 1.617871776103307e-05,
                         'alpha_2_2': 3.420507308734113e-05, 'alpha_2_3': 2.8265094647430282e-05,
                         'alpha_2_4': 2.27763571131237e-05, 'alpha_2_5': 3.489079036344655e-05,
                         'alpha_2_6': 2.241342711437276e-05, 'alpha_2_7': 2.3897698313556626e-05,
                         'alpha_2_8': 3.0498357044587708e-05, 'alpha_2_9': 2.3686506343380093e-05,
                         'alpha_2_10': 1.3492405451475327e-05, 'alpha_2_11': 9.771291344098266e-06,
                         'alpha_2_12': 1.4811240029190232e-05, 'alpha_2_13': 7.293521090508259e-06,
                         'alpha_2_14': 7.5687420625234075e-06, 'alpha_2_15': 1.1845922122084134e-05,
                         'alpha_2_16': 8.793400692481808e-06, 'alpha_2_17': 1.2083163731640221e-05,
                         'alpha_2_18': 6.876941443861951e-06, 'alpha_2_19': 3.0219420570159346e-06,
                         'alpha_3_0': 6.636751454523229e-05, 'alpha_3_1': -1.5852662295391943e-05,
                         'alpha_3_2': -3.360126596207258e-05, 'alpha_3_3': -2.8741863960760136e-05,
                         'alpha_3_4': -2.369688457230944e-05, 'alpha_3_5': -3.573477725535746e-05,
                         'alpha_3_6': -2.2985673224946135e-05, 'alpha_3_7': -2.3858462997820944e-05,
                         'alpha_3_8': -2.9985081579521423e-05, 'alpha_3_9': -2.401946168300636e-05,
                         'alpha_3_10': -1.4318141712001231e-05, 'alpha_3_11': -9.150946122036441e-06,
                         'alpha_3_12': -1.405410701010421e-05, 'alpha_3_13': -5.967990300390515e-06,
                         'alpha_3_14': -6.2472220891872486e-06, 'alpha_3_15': -1.0834960614989424e-05,
                         'alpha_3_16': -6.944935362436211e-06, 'alpha_3_17': -9.310862686904488e-06,
                         'alpha_3_18': -5.271190166174865e-06, 'alpha_3_19': -6.270990817341368e-07,
                         'alpha_spread_5_0': -0.6079252438735796, 'alpha_spread_5_1': -0.09136273131588701,
                         'alpha_spread_5_2': 0.026997227924746254, 'alpha_spread_5_3': 0.021268307784823186,
                         'alpha_spread_5_4': 0.019545750086960086, 'alpha_spread_5_5': 0.006835810711436999,
                         'alpha_spread_5_6': 0.0041411125308261874, 'alpha_spread_5_7': 0.012584106477576634,
                         'alpha_spread_5_8': 0.005580441991450696, 'alpha_spread_5_9': 0.009593275157993974,
                         'alpha_spread_6_0': 0.533919513564041, 'alpha_spread_6_1': 0.16308205692481753,
                         'alpha_spread_6_2': 0.05721488901362866, 'alpha_spread_6_3': -0.112672262860114,
                         'alpha_spread_6_4': -0.07117453551834989, 'alpha_spread_6_5': -0.048132396018800885,
                         'alpha_spread_6_6': 0.060727041541908236, 'alpha_spread_6_7': -0.07875398278675745,
                         'alpha_spread_6_8': -0.014919403892403845, 'alpha_spread_6_9': 0.01695203096869445,
                         'alpha_ret_0': 0.5634616414763483, 'alpha_ret_1': 0.9091012957503244,
                         'alpha_ret_2': 0.9430616276366611, 'alpha_ret_3': 0.8088104003250218,
                         'alpha_ret_4': 0.7149013119686043, 'alpha_ret_5': 0.6231506002200565,
                         'alpha_ret_6': 0.607819984531601, 'alpha_ret_7': 0.4422901733219621,
                         'alpha_ret_8': 0.3288421547173078, 'alpha_ret_9': 0.22166570094075655,
                         'alpha_IF_0': 0.0007013013583514961, 'alpha_IF_1': 0.00037869232717419174,
                         'alpha_IF_2': 0.001263913631086093, 'alpha_IF_3': -0.00023199447594122885,
                         'alpha_IF_4': -0.0017044519814431352, 'alpha_IF_5': -0.003927168871006526,
                         'alpha_IF_6': -0.005972100010454423, 'alpha_IF_7': -0.009313326075118204,
                         'alpha_IF_8': -0.009975678727437822, 'alpha_IF_9': -0.006517144987816125,
                         'alpha_IC_0': -0.0032649074543960573, 'alpha_IC_1': -0.004369931723989976,
                         'alpha_IC_2': -0.003092448714953098, 'alpha_IC_3': -0.0005209558400306068,
                         'alpha_IC_4': 5.86578463225589e-05, 'alpha_IC_5': 0.0006056737430898472,
                         'alpha_IC_6': 0.0012058398323821153, 'alpha_IC_7': 0.002205599673279597,
                         'alpha_IC_8': 0.002767585306050092, 'alpha_IC_9': 0.001994052618121911,
                         'alpha_IH_0': 0.009432754432027773, 'alpha_IH_1': 0.008369473291770768,
                         'alpha_IH_2': 0.004340588199771978, 'alpha_IH_3': 0.0012412502621292742,
                         'alpha_IH_4': 0.0023143832220642565, 'alpha_IH_5': 0.00458849407919518,
                         'alpha_IH_6': 0.006451531916580013, 'alpha_IH_7': 0.009471117314215459,
                         'alpha_IH_8': 0.009281357440907169, 'alpha_IH_9': 0.005672650053281529,
                         'ofi_0': 0.00022270123859919043, 'ofi_1': 0.00024952922533761566,
                         'ofi_2': 0.0002352259879104183, 'ofi_3': 0.0001594920792135178, 'ofi_4': 0.0001232702170189584,
                         'ofi_5': 0.00015743684332026516, 'ofi_6': 7.730085197677337e-05,
                         'ofi_7': 8.107463864006292e-05, 'ofi_8': 7.340020932497265e-05,
                         'ofi_9': 0.00010822718647342778, 'askt_0': -6.566193874643423e-05,
                         'askt_1': -8.850443654925052e-05, 'askt_2': -0.00010387407391518516,
                         'askt_3': 4.93501457532835e-06, 'askt_4': 3.226885239049558e-05,
                         'askt_5': -6.582551127059033e-05, 'askt_6': -1.0316932919548363e-05,
                         'askt_7': -4.932461752620749e-05, 'askt_8': -8.61934703670764e-05,
                         'askt_9': -7.502531658858415e-05, 'bidt_0': 3.3480658842601455e-06,
                         'bidt_1': 1.2276939845676833e-05, 'bidt_2': 2.817643387564616e-05,
                         'bidt_3': -1.7382061267180318e-05, 'bidt_4': -6.247855984817991e-07,
                         'bidt_5': 1.590581961019497e-05, 'bidt_6': 1.5052690041384409e-05,
                         'bidt_7': 3.740142435833579e-05, 'bidt_8': 3.427575575939522e-05,
                         'bidt_9': 6.306960703025582e-05},
              '300623': {'SecuCode': '300623.SZ', 'Interval': 20, 'Intercept': -0.028877953308201747,
                         'alpha_2_0': -2.4306564155928357e-05, 'alpha_2_1': 5.901701460266777e-06,
                         'alpha_2_2': 6.274571738756755e-06, 'alpha_2_3': 4.672327270403934e-06,
                         'alpha_2_4': 2.225456856173854e-06, 'alpha_2_5': 2.8359919620979997e-07,
                         'alpha_2_6': 1.4103038560842483e-06, 'alpha_2_7': 4.877146790126449e-07,
                         'alpha_2_8': 2.5766506954147275e-06, 'alpha_2_9': 1.2010617507984988e-06,
                         'alpha_2_10': -5.1292395752910643e-08, 'alpha_2_11': 2.0424277211077957e-06,
                         'alpha_2_12': 1.4989276300993456e-06, 'alpha_2_13': 2.2813103879563482e-06,
                         'alpha_2_14': 2.035346517105411e-06, 'alpha_2_15': 2.1301786747205395e-06,
                         'alpha_2_16': 1.6241666637458713e-06, 'alpha_2_17': 2.1517985453498746e-06,
                         'alpha_2_18': 4.2708989727110614e-06, 'alpha_2_19': 7.5678967956488335e-06,
                         'alpha_3_0': 2.4120395639612942e-05, 'alpha_3_1': -5.953079891266572e-06,
                         'alpha_3_2': -6.360781621671497e-06, 'alpha_3_3': -4.81985897621701e-06,
                         'alpha_3_4': -2.329153840093945e-06, 'alpha_3_5': -6.196828684229932e-07,
                         'alpha_3_6': -1.5261678649231884e-06, 'alpha_3_7': -5.916758680449622e-07,
                         'alpha_3_8': -2.514371077719068e-06, 'alpha_3_9': -9.5799304583132e-07,
                         'alpha_3_10': 3.3796777928663435e-07, 'alpha_3_11': -1.7973453794558305e-06,
                         'alpha_3_12': -1.3141845845606884e-06, 'alpha_3_13': -2.010947625036371e-06,
                         'alpha_3_14': -1.779434270394942e-06, 'alpha_3_15': -1.747598456908874e-06,
                         'alpha_3_16': -1.3659273997908258e-06, 'alpha_3_17': -1.739653394118367e-06,
                         'alpha_3_18': -3.771831924818028e-06, 'alpha_3_19': -6.913835686965374e-06,
                         'alpha_spread_5_0': -0.16706181463887793, 'alpha_spread_5_1': -0.015971352518723836,
                         'alpha_spread_5_2': 0.03050941260212726, 'alpha_spread_5_3': -0.0011550338572668785,
                         'alpha_spread_5_4': 0.023482085456530206, 'alpha_spread_5_5': -0.0161885620954549,
                         'alpha_spread_5_6': 0.008226167238486851, 'alpha_spread_5_7': -0.011786629496962912,
                         'alpha_spread_5_8': 0.00011040063222045379, 'alpha_spread_5_9': -0.0016780361190189643,
                         'alpha_spread_6_0': 0.5413604580737431, 'alpha_spread_6_1': -0.0011149651502980384,
                         'alpha_spread_6_2': 0.004197822553985856, 'alpha_spread_6_3': 0.007222857360746933,
                         'alpha_spread_6_4': -0.018593154967781987, 'alpha_spread_6_5': 0.029520252792719182,
                         'alpha_spread_6_6': -0.03565939669119792, 'alpha_spread_6_7': -0.019941663579325513,
                         'alpha_spread_6_8': 0.0014703610677691595, 'alpha_spread_6_9': 0.018832623509030415,
                         'alpha_ret_0': 0.5963868887097484, 'alpha_ret_1': 0.6484976694040275,
                         'alpha_ret_2': 0.5232540145980917, 'alpha_ret_3': 0.3406769566790674,
                         'alpha_ret_4': 0.12714092008977418, 'alpha_ret_5': 0.011650169038782849,
                         'alpha_ret_6': -0.09015944157375562, 'alpha_ret_7': -0.15987358050485848,
                         'alpha_ret_8': -0.18906545140250777, 'alpha_ret_9': -0.16594039321072007,
                         'alpha_IF_0': -0.0005444105596573009, 'alpha_IF_1': 0.0008699234986236383,
                         'alpha_IF_2': 0.0006153228008627827, 'alpha_IF_3': 0.00048473150616276965,
                         'alpha_IF_4': 0.00027244671382672145, 'alpha_IF_5': -1.2861442353796468e-05,
                         'alpha_IF_6': 0.00017799483507016049, 'alpha_IF_7': 0.0004917620760677613,
                         'alpha_IF_8': 0.0006009259288025893, 'alpha_IF_9': -1.17878630047802e-05,
                         'alpha_IC_0': -0.0004881272517413786, 'alpha_IC_1': -0.00122019896929739,
                         'alpha_IC_2': -0.0008129520905290357, 'alpha_IC_3': -0.0008037145658068047,
                         'alpha_IC_4': -0.00036569866749288754, 'alpha_IC_5': -0.00016037522669430713,
                         'alpha_IC_6': 0.0004006956429521903, 'alpha_IC_7': 0.0003486661682207041,
                         'alpha_IC_8': 0.00032353701319647873, 'alpha_IC_9': 0.0004333827413861293,
                         'alpha_IH_0': 0.0006972877696404972, 'alpha_IH_1': 0.0012767396684052986,
                         'alpha_IH_2': 0.0008042085368413204, 'alpha_IH_3': 0.0009707269240554389,
                         'alpha_IH_4': 0.0003918123881574817, 'alpha_IH_5': 0.0003525908130933503,
                         'alpha_IH_6': -0.001123042864682485, 'alpha_IH_7': -0.0015069562706415327,
                         'alpha_IH_8': -0.001610398841029891, 'alpha_IH_9': -0.0009243237792598623,
                         'ofi_0': 1.378504196652134e-05, 'ofi_1': 9.74580270940589e-06, 'ofi_2': 6.147972106653023e-06,
                         'ofi_3': 2.745662260077946e-06, 'ofi_4': -6.909539857397129e-07,
                         'ofi_5': -1.1263062206925818e-06, 'ofi_6': -2.0419683045407076e-06,
                         'ofi_7': -2.471596448935836e-06, 'ofi_8': -1.846239240708452e-06,
                         'ofi_9': -3.2179636090128397e-06, 'askt_0': 2.1816484642057536e-08,
                         'askt_1': -2.7013925137630894e-06, 'askt_2': -9.348219741657026e-07,
                         'askt_3': 4.079432110251226e-07, 'askt_4': 2.018540066532023e-06,
                         'askt_5': 1.336237578409484e-06, 'askt_6': 2.1696509936387503e-06,
                         'askt_7': 2.845136654720129e-06, 'askt_8': 4.644563383669754e-06,
                         'askt_9': 3.46986495460688e-06, 'bidt_0': -5.491177824893968e-06,
                         'bidt_1': -7.3926549348236554e-06, 'bidt_2': -8.767027010138947e-06,
                         'bidt_3': -9.48524232197929e-06, 'bidt_4': -1.0503079775037288e-05,
                         'bidt_5': -1.1307759544183855e-05, 'bidt_6': -1.2158669433526134e-05,
                         'bidt_7': -1.0930205713261814e-05, 'bidt_8': -8.175798963221183e-06,
                         'bidt_9': -1.1245296485705227e-05},
              '600329': {'SecuCode': '600329.SH', 'Interval': 20, 'Intercept': 0.00690407923458136,
                         'alpha_2_0': -1.4422881335736274e-05, 'alpha_2_1': 2.688422523830463e-06,
                         'alpha_2_2': 4.267634967108084e-06, 'alpha_2_3': 6.3523067762760296e-06,
                         'alpha_2_4': 1.6719528041914779e-06, 'alpha_2_5': 1.2724199187223106e-07,
                         'alpha_2_6': 1.4482584727282737e-06, 'alpha_2_7': 1.080733890280941e-06,
                         'alpha_2_8': 1.6489518237303896e-06, 'alpha_2_9': -2.0356338337839348e-06,
                         'alpha_2_10': -1.344288629698142e-06, 'alpha_2_11': -7.96837914690464e-07,
                         'alpha_2_12': -1.1570757113215521e-06, 'alpha_2_13': -6.908256724230381e-07,
                         'alpha_2_14': 1.0545208018726089e-06, 'alpha_2_15': 1.761333589159481e-08,
                         'alpha_2_16': 1.0415180182772566e-06, 'alpha_2_17': -3.336520347517265e-07,
                         'alpha_2_18': 1.8435117523409162e-06, 'alpha_2_19': -6.455288721172267e-07,
                         'alpha_3_0': 1.5071895664830162e-05, 'alpha_3_1': -1.6889262133943505e-06,
                         'alpha_3_2': -3.552282490399791e-06, 'alpha_3_3': -6.129774486223368e-06,
                         'alpha_3_4': -1.6859381850337476e-06, 'alpha_3_5': -3.3073949869044307e-07,
                         'alpha_3_6': -1.6092234172327252e-06, 'alpha_3_7': -1.27168741058863e-06,
                         'alpha_3_8': -1.447275825292216e-06, 'alpha_3_9': 2.1517368679531442e-06,
                         'alpha_3_10': 1.3782934485747948e-06, 'alpha_3_11': 7.528961828167789e-07,
                         'alpha_3_12': 1.0024182811051185e-06, 'alpha_3_13': 7.028619061179983e-07,
                         'alpha_3_14': -1.1232871379380821e-06, 'alpha_3_15': 2.467037026694032e-07,
                         'alpha_3_16': -9.22808032358113e-07, 'alpha_3_17': 6.601011507468376e-07,
                         'alpha_3_18': -1.4617341164191966e-06, 'alpha_3_19': 1.0804878708837602e-06,
                         'alpha_spread_5_0': -0.36941931784447074, 'alpha_spread_5_1': 0.2122298655852193,
                         'alpha_spread_5_2': 0.09801475913895415, 'alpha_spread_5_3': 0.02127355786910321,
                         'alpha_spread_5_4': 0.06781609516928407, 'alpha_spread_5_5': -0.04445613880406745,
                         'alpha_spread_5_6': -0.0445660724228821, 'alpha_spread_5_7': -0.029704466388894492,
                         'alpha_spread_5_8': 0.009830486093569176, 'alpha_spread_5_9': 0.025303176536323604,
                         'alpha_spread_6_0': -0.04816862207123704, 'alpha_spread_6_1': -0.02489727732349214,
                         'alpha_spread_6_2': 0.005658860587680349, 'alpha_spread_6_3': -0.0052046751704518356,
                         'alpha_spread_6_4': 0.012146795751334217, 'alpha_spread_6_5': 0.00239401943049851,
                         'alpha_spread_6_6': -0.0015264005109195751, 'alpha_spread_6_7': -0.0027877562892336697,
                         'alpha_spread_6_8': 0.00084025136739023, 'alpha_spread_6_9': -0.006392871629885723,
                         'alpha_ret_0': 0.055945567878506255, 'alpha_ret_1': 0.22127170923657333,
                         'alpha_ret_2': 0.23417642526732527, 'alpha_ret_3': 0.18048290817246276,
                         'alpha_ret_4': 0.08259143337808914, 'alpha_ret_5': 0.03740325326093613,
                         'alpha_ret_6': 0.053396008012488096, 'alpha_ret_7': 0.062108723836133084,
                         'alpha_ret_8': 0.05424994214047688, 'alpha_ret_9': 0.058153234086580775,
                         'alpha_IF_0': -0.0006786478786945878, 'alpha_IF_1': -0.002188724020536386,
                         'alpha_IF_2': -0.0025328055766910755, 'alpha_IF_3': -0.0025637341297393154,
                         'alpha_IF_4': -0.002630032782895754, 'alpha_IF_5': -0.0017629351738952625,
                         'alpha_IF_6': -0.0013311201893625466, 'alpha_IF_7': -0.000562907221603531,
                         'alpha_IF_8': -1.7499735380882544e-05, 'alpha_IF_9': -0.00023483479332468942,
                         'alpha_IC_0': -0.0003456454456488962, 'alpha_IC_1': 0.0016340967546696098,
                         'alpha_IC_2': 0.001560809372751177, 'alpha_IC_3': 0.0016388422685266373,
                         'alpha_IC_4': 0.001713851522013882, 'alpha_IC_5': 0.0011202948701753348,
                         'alpha_IC_6': 0.0010015174542452334, 'alpha_IC_7': 0.000897160427584162,
                         'alpha_IC_8': 0.0008886767350604066, 'alpha_IC_9': 0.0007503420591337313,
                         'alpha_IH_0': 0.001799730317382339, 'alpha_IH_1': -0.00019353419645116453,
                         'alpha_IH_2': 0.0004905570763464066, 'alpha_IH_3': 0.0003895511107445603,
                         'alpha_IH_4': 0.00030346897253358116, 'alpha_IH_5': 0.0002724147152765631,
                         'alpha_IH_6': -0.00012655072373440876, 'alpha_IH_7': -0.001067915767408343,
                         'alpha_IH_8': -0.0018740869914386814, 'alpha_IH_9': -0.0012417147725516788,
                         'ofi_0': 8.461448557871586e-06, 'ofi_1': -9.58219486493161e-07, 'ofi_2': 2.752982280749789e-08,
                         'ofi_3': 3.879414699678503e-07, 'ofi_4': 1.935082227272903e-06, 'ofi_5': 1.405251491420574e-06,
                         'ofi_6': 1.4677505326946478e-06, 'ofi_7': 2.6325121965470757e-06,
                         'ofi_8': 3.1188825621776092e-06, 'ofi_9': 6.275830588359482e-06, 'askt_0': 4.3168686032509e-07,
                         'askt_1': 1.4655476449859858e-06, 'askt_2': 6.148902309247978e-08,
                         'askt_3': -8.847782448379461e-08, 'askt_4': -1.4948515823628094e-06,
                         'askt_5': -8.381669822516092e-07, 'askt_6': 7.185285592318717e-09,
                         'askt_7': 4.5449431710377353e-07, 'askt_8': 1.4895289980860713e-06,
                         'askt_9': 1.6079345763004864e-07, 'bidt_0': 1.7694497935573378e-06,
                         'bidt_1': 1.78950375828586e-06, 'bidt_2': 9.254048797244541e-07,
                         'bidt_3': 5.436445825756438e-07, 'bidt_4': 2.0382473995943953e-07,
                         'bidt_5': 7.035830903120877e-07, 'bidt_6': 1.4873620295010358e-07,
                         'bidt_7': 1.2127156387949864e-06, 'bidt_8': -9.977563910268453e-08,
                         'bidt_9': 1.984368925151958e-06},
              '603976': {'SecuCode': '603976.SH', 'Interval': 20, 'Intercept': -0.0076911472819221624,
                         'alpha_2_0': -7.131202426273972e-05, 'alpha_2_1': -2.5511614243851658e-05,
                         'alpha_2_2': -1.3628370142167092e-05, 'alpha_2_3': -8.79639771729869e-06,
                         'alpha_2_4': -7.24470726944083e-06, 'alpha_2_5': -1.0033995948681775e-05,
                         'alpha_2_6': -1.6799291245220073e-06, 'alpha_2_7': -1.3815794599139926e-07,
                         'alpha_2_8': 2.319317072460015e-06, 'alpha_2_9': 3.6467172516856153e-06,
                         'alpha_2_10': -4.505130738713341e-06, 'alpha_2_11': 9.755262780634176e-06,
                         'alpha_2_12': 5.619853002064352e-06, 'alpha_2_13': 1.0155702287740535e-05,
                         'alpha_2_14': 9.998642906112768e-06, 'alpha_2_15': 9.822413477493563e-06,
                         'alpha_2_16': 9.081889544342005e-06, 'alpha_2_17': 9.20280453136413e-06,
                         'alpha_2_18': 1.2637350397654781e-05, 'alpha_2_19': 1.2719599330877746e-05,
                         'alpha_3_0': 7.269841039701624e-05, 'alpha_3_1': 2.5443860475257128e-05,
                         'alpha_3_2': 1.3378381478882393e-05, 'alpha_3_3': 8.259726723582123e-06,
                         'alpha_3_4': 6.7250611816957595e-06, 'alpha_3_5': 9.606046615336714e-06,
                         'alpha_3_6': 1.181499466255361e-06, 'alpha_3_7': -1.4592513609468586e-07,
                         'alpha_3_8': -2.2811794797853178e-06, 'alpha_3_9': -3.1369469455591636e-06,
                         'alpha_3_10': 5.060640847920721e-06, 'alpha_3_11': -9.004203237232701e-06,
                         'alpha_3_12': -5.182115845004784e-06, 'alpha_3_13': -9.42638307007362e-06,
                         'alpha_3_14': -9.311585996855318e-06, 'alpha_3_15': -8.745406715539724e-06,
                         'alpha_3_16': -8.46429960415937e-06, 'alpha_3_17': -8.49679741269584e-06,
                         'alpha_3_18': -1.2324220780423233e-05, 'alpha_3_19': -1.1893605530050804e-05,
                         'alpha_spread_5_0': -0.5083083567164154, 'alpha_spread_5_1': -0.006758988389904022,
                         'alpha_spread_5_2': -0.0019278531518331732, 'alpha_spread_5_3': 0.001619815910770753,
                         'alpha_spread_5_4': -0.005436031284363685, 'alpha_spread_5_5': 0.009374310999240503,
                         'alpha_spread_5_6': 0.0053260114832040465, 'alpha_spread_5_7': -0.009323439703077058,
                         'alpha_spread_5_8': 0.008002074969034656, 'alpha_spread_5_9': -0.017591412636408125,
                         'alpha_spread_6_0': 0.6462072521780008, 'alpha_spread_6_1': 0.02022256786232074,
                         'alpha_spread_6_2': 0.0012855665260060405, 'alpha_spread_6_3': -0.052282086833626076,
                         'alpha_spread_6_4': 0.023600508532499613, 'alpha_spread_6_5': -0.039298517888207714,
                         'alpha_spread_6_6': 0.03180838673039703, 'alpha_spread_6_7': -0.04411386442136355,
                         'alpha_spread_6_8': -0.07997462374524635, 'alpha_spread_6_9': 0.02946421302142074,
                         'alpha_ret_0': 0.893217893087115, 'alpha_ret_1': 1.0892471095312923,
                         'alpha_ret_2': 0.9219946756730689, 'alpha_ret_3': 0.6501998451604852,
                         'alpha_ret_4': 0.4565403422226448, 'alpha_ret_5': 0.32179496794284856,
                         'alpha_ret_6': 0.1827689001706974, 'alpha_ret_7': 0.09784413525337834,
                         'alpha_ret_8': -0.06221814986922745, 'alpha_ret_9': -0.11738637868981272,
                         'alpha_IF_0': -0.0016123125544596282, 'alpha_IF_1': -0.003275578943267382,
                         'alpha_IF_2': -0.004607600818809079, 'alpha_IF_3': -0.005571818881753421,
                         'alpha_IF_4': -0.004595592291942649, 'alpha_IF_5': -0.0043673462174297975,
                         'alpha_IF_6': -0.003752271200405233, 'alpha_IF_7': -0.0029022795833387157,
                         'alpha_IF_8': -0.0020526581801085246, 'alpha_IF_9': -0.0008071685725727648,
                         'alpha_IC_0': 0.0005742633958093198, 'alpha_IC_1': 0.0015577111434868873,
                         'alpha_IC_2': 0.0013369460018624285, 'alpha_IC_3': 0.0017615754294590892,
                         'alpha_IC_4': 0.0010328739881271616, 'alpha_IC_5': 0.0012403949294065304,
                         'alpha_IC_6': 0.0011115921526843992, 'alpha_IC_7': 0.0007893906415904575,
                         'alpha_IC_8': 0.0009173654575588716, 'alpha_IC_9': 0.00014130031664152433,
                         'alpha_IH_0': 0.0012091592807592277, 'alpha_IH_1': 0.0015810380513302418,
                         'alpha_IH_2': 0.004101611842118832, 'alpha_IH_3': 0.004707192830935759,
                         'alpha_IH_4': 0.004764454313961747, 'alpha_IH_5': 0.004001369415014188,
                         'alpha_IH_6': 0.003363236458429303, 'alpha_IH_7': 0.0027447590075074953,
                         'alpha_IH_8': 0.0012279289524966743, 'alpha_IH_9': 0.0009567768996085049,
                         'ofi_0': 4.761414947680151e-05, 'ofi_1': 2.9746150484242793e-05,
                         'ofi_2': 2.4572583224919353e-05, 'ofi_3': 9.341256609244864e-06, 'ofi_4': 4.22374190962407e-06,
                         'ofi_5': 8.39691122722525e-06, 'ofi_6': 5.951659286890752e-06, 'ofi_7': 4.640466955747323e-07,
                         'ofi_8': -8.873305647417113e-06, 'ofi_9': -1.5161768115749926e-05,
                         'askt_0': 7.184849490855947e-05, 'askt_1': 7.573431436820657e-06,
                         'askt_2': -3.665919735852735e-05, 'askt_3': 6.531698260429578e-06,
                         'askt_4': -5.665591440137121e-05, 'askt_5': -5.432079934512572e-05,
                         'askt_6': -3.4163570582784394e-05, 'askt_7': -4.55672642999417e-05,
                         'askt_8': -3.104814230956232e-05, 'askt_9': -1.173165219280929e-05,
                         'bidt_0': 1.5049221542224657e-05, 'bidt_1': 3.2012290001763466e-05,
                         'bidt_2': 1.992827784569758e-05, 'bidt_3': 2.7472182635347703e-05,
                         'bidt_4': -5.332533198048899e-05, 'bidt_5': -2.3006527260279734e-05,
                         'bidt_6': -2.2357391848979706e-05, 'bidt_7': -9.412888032825415e-06,
                         'bidt_8': -1.2013459268418142e-05, 'bidt_9': -1.5071022967723843e-05},
              '600702': {'SecuCode': '600702.SH', 'Interval': 20, 'Intercept': -0.053288757387476515,
                         'alpha_2_0': -3.537113424951945e-05, 'alpha_2_1': -3.1914848309548705e-06,
                         'alpha_2_2': -1.0899665136902313e-05, 'alpha_2_3': -1.1098057655920205e-05,
                         'alpha_2_4': -8.508950501766459e-06, 'alpha_2_5': -7.450026703973177e-06,
                         'alpha_2_6': -1.5002153110567368e-06, 'alpha_2_7': 4.76483551518196e-06,
                         'alpha_2_8': -2.7646342687323074e-05, 'alpha_2_9': -1.2997949333765051e-05,
                         'alpha_2_10': -5.016658529467173e-07, 'alpha_2_11': 5.719181026404798e-06,
                         'alpha_2_12': 4.4380855332716814e-06, 'alpha_2_13': -1.185590029974704e-06,
                         'alpha_2_14': 3.787309910070101e-06, 'alpha_2_15': 6.009031484657796e-06,
                         'alpha_2_16': 8.009710903695246e-06, 'alpha_2_17': 1.504798110208486e-05,
                         'alpha_2_18': 1.330050872927782e-05, 'alpha_2_19': 1.5611055541202073e-05,
                         'alpha_3_0': 3.828000130183304e-05, 'alpha_3_1': 6.131447151073406e-06,
                         'alpha_3_2': 1.3305765328912231e-05, 'alpha_3_3': 1.5055846898690929e-05,
                         'alpha_3_4': 1.1210283665053812e-05, 'alpha_3_5': 1.0755611274911598e-05,
                         'alpha_3_6': 4.703087804376222e-06, 'alpha_3_7': -7.34163210578572e-07,
                         'alpha_3_8': 3.2463700232488635e-05, 'alpha_3_9': 1.6928691585401625e-05,
                         'alpha_3_10': 4.273233587886148e-06, 'alpha_3_11': -1.6803078166227708e-06,
                         'alpha_3_12': 2.623194927637656e-07, 'alpha_3_13': 4.552329782482391e-06,
                         'alpha_3_14': -8.325320911912193e-07, 'alpha_3_15': -1.4422411051809036e-06,
                         'alpha_3_16': -5.402268788694983e-06, 'alpha_3_17': -1.3295355861397904e-05,
                         'alpha_3_18': -1.1363652195826888e-05, 'alpha_3_19': -1.3470843297374691e-05,
                         'alpha_spread_5_0': -0.5535058241872283, 'alpha_spread_5_1': 0.033050476946887515,
                         'alpha_spread_5_2': 0.010319980680500449, 'alpha_spread_5_3': 0.003959357334701172,
                         'alpha_spread_5_4': 0.0012577328140198542, 'alpha_spread_5_5': 0.033111050011921016,
                         'alpha_spread_5_6': -0.0008253737653856226, 'alpha_spread_5_7': -0.04098700250375392,
                         'alpha_spread_5_8': -0.008812635602928965, 'alpha_spread_5_9': -0.02519662729721718,
                         'alpha_spread_6_0': 0.5555299319922399, 'alpha_spread_6_1': -0.011368000065803673,
                         'alpha_spread_6_2': -0.026113337934164718, 'alpha_spread_6_3': -0.014433483022984814,
                         'alpha_spread_6_4': -0.0151381797339759, 'alpha_spread_6_5': -0.009561178684423986,
                         'alpha_spread_6_6': 0.016989186441650768, 'alpha_spread_6_7': -0.0031754593092954567,
                         'alpha_spread_6_8': 0.025274568267078027, 'alpha_spread_6_9': -0.028152388559733857,
                         'alpha_ret_0': 0.027691971575264332, 'alpha_ret_1': -0.005285905247004002,
                         'alpha_ret_2': -0.02409847371239598, 'alpha_ret_3': -0.03260566474286644,
                         'alpha_ret_4': -0.04101451295876179, 'alpha_ret_5': -0.08293378948225465,
                         'alpha_ret_6': -0.0827314866833503, 'alpha_ret_7': -0.3218468619560894,
                         'alpha_ret_8': -0.036913861785432954, 'alpha_ret_9': -0.011572809444175358,
                         'alpha_IF_0': 0.010916786311664456, 'alpha_IF_1': 0.02337275685298582,
                         'alpha_IF_2': 0.024010370692171466, 'alpha_IF_3': 0.02321452516417111,
                         'alpha_IF_4': 0.019583790125208535, 'alpha_IF_5': 0.015813706893096063,
                         'alpha_IF_6': 0.020241040204501865, 'alpha_IF_7': 0.023270232101607443,
                         'alpha_IF_8': 0.027198645880871467, 'alpha_IF_9': 0.016422738835882487,
                         'alpha_IC_0': -0.017512075337861234, 'alpha_IC_1': -0.007298714837237648,
                         'alpha_IC_2': -0.005461924375969007, 'alpha_IC_3': -0.005337363396555163,
                         'alpha_IC_4': -0.0036574131452077924, 'alpha_IC_5': -0.0005826966537555543,
                         'alpha_IC_6': -0.0032504767973282702, 'alpha_IC_7': -0.0070811083511109225,
                         'alpha_IC_8': -0.012212125797388354, 'alpha_IC_9': -0.005339427133008409,
                         'alpha_IH_0': -0.012334423942465448, 'alpha_IH_1': -0.01983969233267696,
                         'alpha_IH_2': -0.024621161810115023, 'alpha_IH_3': -0.023516975093983268,
                         'alpha_IH_4': -0.021400068456541067, 'alpha_IH_5': -0.02229045860514182,
                         'alpha_IH_6': -0.02349028318653897, 'alpha_IH_7': -0.019868430383013693,
                         'alpha_IH_8': -0.014993900190353909, 'alpha_IH_9': -0.013346298317691284,
                         'ofi_0': 0.00021196303279784318, 'ofi_1': 0.00013622198876011042,
                         'ofi_2': 4.2255099741294096e-05, 'ofi_3': 3.792778171364572e-05,
                         'ofi_4': 2.088764831198838e-05, 'ofi_5': 5.566944556975214e-05, 'ofi_6': 2.978121786578951e-05,
                         'ofi_7': 3.2900027912086775e-06, 'ofi_8': -3.3708029741543195e-05,
                         'ofi_9': -5.0104630407227884e-05, 'askt_0': 6.658878853163037e-05,
                         'askt_1': 2.6115806922539525e-05, 'askt_2': 2.2289053812855406e-05,
                         'askt_3': 1.907704612386004e-05, 'askt_4': 1.72003087860555e-05,
                         'askt_5': 1.205868780060818e-05, 'askt_6': 8.988710423289658e-06,
                         'askt_7': 9.459775969763573e-06, 'askt_8': 1.1084835952415962e-05,
                         'askt_9': 4.917487040110211e-06, 'bidt_0': -8.102978413177034e-06,
                         'bidt_1': -3.56937953684003e-06, 'bidt_2': -5.605786091739586e-06,
                         'bidt_3': -3.193942307129945e-06, 'bidt_4': 2.5614967250843474e-06,
                         'bidt_5': 1.1557538760988802e-05, 'bidt_6': 6.1009716041610265e-06,
                         'bidt_7': 6.379918331824447e-06, 'bidt_8': -3.476575063298509e-07,
                         'bidt_9': 5.132163677201441e-06},
              '603126': {'SecuCode': '603126.SH', 'Interval': 20, 'Intercept': -0.003739153528827258,
                         'alpha_2_0': -8.708104091096398e-06, 'alpha_2_1': -4.019692797788949e-06,
                         'alpha_2_2': -2.069359001616164e-06, 'alpha_2_3': -1.1363616865949976e-06,
                         'alpha_2_4': -9.498855429618159e-08, 'alpha_2_5': 5.405318401812555e-07,
                         'alpha_2_6': 5.636205146852138e-07, 'alpha_2_7': 9.293682653375902e-07,
                         'alpha_2_8': 1.028046088497253e-06, 'alpha_2_9': 1.3171914836593315e-06,
                         'alpha_2_10': 7.440816139581545e-07, 'alpha_2_11': 1.0687347724189427e-06,
                         'alpha_2_12': 8.884028973547575e-07, 'alpha_2_13': 6.321964423172818e-07,
                         'alpha_2_14': 5.525781922259758e-07, 'alpha_2_15': 1.0298061016698702e-06,
                         'alpha_2_16': 1.1703852291164668e-06, 'alpha_2_17': 1.300604631273753e-06,
                         'alpha_2_18': 1.1983564497195288e-06, 'alpha_2_19': 6.86019702425935e-07,
                         'alpha_3_0': 8.566809306189302e-06, 'alpha_3_1': 3.973259730800449e-06,
                         'alpha_3_2': 2.0543592019416794e-06, 'alpha_3_3': 1.1160172087915948e-06,
                         'alpha_3_4': 1.3102971081464305e-07, 'alpha_3_5': -4.954615853538515e-07,
                         'alpha_3_6': -5.041465108683278e-07, 'alpha_3_7': -8.34161437947075e-07,
                         'alpha_3_8': -9.339153720018011e-07, 'alpha_3_9': -1.2369133055458423e-06,
                         'alpha_3_10': -7.204600017804208e-07, 'alpha_3_11': -1.0526484819160747e-06,
                         'alpha_3_12': -8.634641423616975e-07, 'alpha_3_13': -6.16905384355103e-07,
                         'alpha_3_14': -5.468317561892265e-07, 'alpha_3_15': -9.983945916218484e-07,
                         'alpha_3_16': -1.1126252171237626e-06, 'alpha_3_17': -1.296992574754744e-06,
                         'alpha_3_18': -1.2017811993586862e-06, 'alpha_3_19': -7.059809709953472e-07,
                         'alpha_spread_5_0': -0.03165551068323341, 'alpha_spread_5_1': -0.02229872022018701,
                         'alpha_spread_5_2': 0.003006819359485373, 'alpha_spread_5_3': 0.005425480569549747,
                         'alpha_spread_5_4': -0.004449438198937611, 'alpha_spread_5_5': 0.0013836183097871715,
                         'alpha_spread_5_6': 0.00319515587376696, 'alpha_spread_5_7': -0.0015120720754191737,
                         'alpha_spread_5_8': 0.013140593575721764, 'alpha_spread_5_9': 0.003739541445234289,
                         'alpha_spread_6_0': 0.07728251823313077, 'alpha_spread_6_1': 0.012726966787715425,
                         'alpha_spread_6_2': 0.0011785158048252795, 'alpha_spread_6_3': 0.001639660319244933,
                         'alpha_spread_6_4': 0.005575303929018, 'alpha_spread_6_5': -0.004772993391495995,
                         'alpha_spread_6_6': 0.0010821667305828896, 'alpha_spread_6_7': 0.0005089361321675096,
                         'alpha_spread_6_8': -0.013891845598338082, 'alpha_spread_6_9': 0.003606708543162346,
                         'alpha_ret_0': -0.2162571615666311, 'alpha_ret_1': 0.012439416712370917,
                         'alpha_ret_2': 0.10396802725602196, 'alpha_ret_3': 0.12825594045901428,
                         'alpha_ret_4': 0.10576245712244539, 'alpha_ret_5': 0.08772663010511697,
                         'alpha_ret_6': 0.07566988923706135, 'alpha_ret_7': 0.04873499632987769,
                         'alpha_ret_8': 0.02277304282733562, 'alpha_ret_9': -0.0024528517371359294,
                         'alpha_IF_0': -0.0001701738619427599, 'alpha_IF_1': -0.000456973064324854,
                         'alpha_IF_2': -0.0005262728887327287, 'alpha_IF_3': -0.0003985824510883303,
                         'alpha_IF_4': -0.00034651510696636067, 'alpha_IF_5': -0.00024059002193819616,
                         'alpha_IF_6': -8.35924151954864e-05, 'alpha_IF_7': -0.00010020642636726962,
                         'alpha_IF_8': -6.537504457939624e-05, 'alpha_IF_9': -3.3659350617285054e-05,
                         'alpha_IC_0': -4.027830132704278e-05, 'alpha_IC_1': 6.245969203202315e-05,
                         'alpha_IC_2': 0.00012954110488687756, 'alpha_IC_3': 3.821571258158568e-06,
                         'alpha_IC_4': 2.5377603023070684e-05, 'alpha_IC_5': 5.824801970427201e-06,
                         'alpha_IC_6': -9.521767557570109e-05, 'alpha_IC_7': -7.96710750784224e-05,
                         'alpha_IC_8': -4.792216027427891e-05, 'alpha_IC_9': -5.6638071141349195e-05,
                         'alpha_IH_0': 0.0002563258738731971, 'alpha_IH_1': 0.0005478533675398624,
                         'alpha_IH_2': 0.0005081542270516133, 'alpha_IH_3': 0.0005886572979724526,
                         'alpha_IH_4': 0.00045829359078973666, 'alpha_IH_5': 0.00034360438283473333,
                         'alpha_IH_6': 0.000323612258134818, 'alpha_IH_7': 0.00031527823630435586,
                         'alpha_IH_8': 0.0002069669298497242, 'alpha_IH_9': 0.00017759603936353608,
                         'ofi_0': 8.034226101813216e-07, 'ofi_1': 1.4244810269446016e-07,
                         'ofi_2': 1.7397214896276345e-07, 'ofi_3': 1.294938619501568e-07,
                         'ofi_4': 1.9105013542836782e-07, 'ofi_5': -4.871360529960854e-10,
                         'ofi_6': -1.52916074152711e-07, 'ofi_7': -8.134680483326888e-08,
                         'ofi_8': -2.7308898786914633e-07, 'ofi_9': -3.2532144835256954e-07,
                         'askt_0': 8.007523595376505e-06, 'askt_1': 3.402089631705234e-06,
                         'askt_2': 1.7367701598742565e-06, 'askt_3': 1.7075188757675988e-06,
                         'askt_4': -4.067819821735712e-09, 'askt_5': 1.5578918697581531e-06,
                         'askt_6': 2.0747456926834916e-06, 'askt_7': 2.325674945810532e-06,
                         'askt_8': 2.3067578729807614e-06, 'askt_9': 2.225577982091508e-06,
                         'bidt_0': -2.7443063049920663e-06, 'bidt_1': -2.5903045491091087e-06,
                         'bidt_2': -2.3956473690026882e-06, 'bidt_3': -2.802547240485821e-06,
                         'bidt_4': -2.8864750378130925e-06, 'bidt_5': -2.931188771506808e-06,
                         'bidt_6': -3.025037002598574e-06, 'bidt_7': -3.5728819928517857e-06,
                         'bidt_8': -3.951900843974777e-06, 'bidt_9': -3.586595417772397e-06},
              '603222': {'SecuCode': '603222.SH', 'Interval': 20, 'Intercept': -0.003548924381094033,
                         'alpha_2_0': -2.260335690051803e-05, 'alpha_2_1': -8.330439747017891e-06,
                         'alpha_2_2': 3.485067797334785e-07, 'alpha_2_3': -3.219462203897779e-06,
                         'alpha_2_4': 1.2566365394313838e-06, 'alpha_2_5': 1.8048195991966297e-06,
                         'alpha_2_6': 2.1067037839036287e-06, 'alpha_2_7': 1.2837534235477538e-06,
                         'alpha_2_8': 3.0745574548897367e-06, 'alpha_2_9': 1.30202365460687e-06,
                         'alpha_2_10': 2.038447437483378e-07, 'alpha_2_11': 1.6518567912247446e-07,
                         'alpha_2_12': 8.57710886929437e-07, 'alpha_2_13': 3.798589981994978e-07,
                         'alpha_2_14': 1.6788878638564075e-06, 'alpha_2_15': 5.527928340029115e-07,
                         'alpha_2_16': 9.561627532720625e-07, 'alpha_2_17': 1.9557201052231844e-06,
                         'alpha_2_18': 1.2424442215245505e-06, 'alpha_2_19': 1.6982313965154889e-06,
                         'alpha_3_0': 2.277572638094665e-05, 'alpha_3_1': 8.346736269522437e-06,
                         'alpha_3_2': -4.2850371313428694e-07, 'alpha_3_3': 3.1527142965812515e-06,
                         'alpha_3_4': -1.3799057833462493e-06, 'alpha_3_5': -1.973335182836328e-06,
                         'alpha_3_6': -2.1753071534683564e-06, 'alpha_3_7': -1.3846401808480406e-06,
                         'alpha_3_8': -3.22002738651742e-06, 'alpha_3_9': -1.4434432084650078e-06,
                         'alpha_3_10': -3.6209797231614377e-07, 'alpha_3_11': -2.8316003763456355e-07,
                         'alpha_3_12': -8.54037676049882e-07, 'alpha_3_13': -3.6182479987091667e-07,
                         'alpha_3_14': -1.7317553646952717e-06, 'alpha_3_15': -5.886015160108292e-07,
                         'alpha_3_16': -1.002451360863635e-06, 'alpha_3_17': -2.0019597873456377e-06,
                         'alpha_3_18': -1.2159618277863481e-06, 'alpha_3_19': -1.7943655826477731e-06,
                         'alpha_spread_5_0': -0.03619443619334648, 'alpha_spread_5_1': -0.03432723599820832,
                         'alpha_spread_5_2': -0.010778213734719051, 'alpha_spread_5_3': 0.016050677944643838,
                         'alpha_spread_5_4': -0.005891099213256917, 'alpha_spread_5_5': 0.0039246589413240805,
                         'alpha_spread_5_6': 0.005511342235717457, 'alpha_spread_5_7': 0.003781810031910193,
                         'alpha_spread_5_8': 0.004648648508899768, 'alpha_spread_5_9': 0.010822528473688267,
                         'alpha_spread_6_0': 0.15571170737549417, 'alpha_spread_6_1': 0.0024794272707457737,
                         'alpha_spread_6_2': 0.020345721994445086, 'alpha_spread_6_3': -0.007906532058203842,
                         'alpha_spread_6_4': -0.002719685606083116, 'alpha_spread_6_5': 0.00024178777148887531,
                         'alpha_spread_6_6': -0.0007270872607575905, 'alpha_spread_6_7': 0.0017968102964007237,
                         'alpha_spread_6_8': -0.02109473237465205, 'alpha_spread_6_9': -0.007281318451238473,
                         'alpha_ret_0': -0.004809254067368205, 'alpha_ret_1': 0.4321923386188554,
                         'alpha_ret_2': 0.0507799088661121, 'alpha_ret_3': 0.29118925312122856,
                         'alpha_ret_4': 0.03828409217317368, 'alpha_ret_5': 0.03872630112239774,
                         'alpha_ret_6': 0.013201291716281762, 'alpha_ret_7': -0.0019224261131381753,
                         'alpha_ret_8': -0.06677654112609148, 'alpha_ret_9': -0.015910222862331534,
                         'alpha_IF_0': -0.00015928530413994346, 'alpha_IF_1': 0.0013145889533182032,
                         'alpha_IF_2': 0.0010192422661661012, 'alpha_IF_3': 0.0006216390901770887,
                         'alpha_IF_4': 0.000104558677185728, 'alpha_IF_5': -0.00044698366944240497,
                         'alpha_IF_6': -0.0010701185386861219, 'alpha_IF_7': -0.0012698142889546247,
                         'alpha_IF_8': -0.001016633884100474, 'alpha_IF_9': -0.0007669876068833465,
                         'alpha_IC_0': -0.0004813168671612811, 'alpha_IC_1': -0.0009094235395234801,
                         'alpha_IC_2': -0.0010872772117582702, 'alpha_IC_3': -0.0009646858939837041,
                         'alpha_IC_4': -0.00062947356147878, 'alpha_IC_5': -0.00045805231185963753,
                         'alpha_IC_6': -0.0003169504141079831, 'alpha_IC_7': -8.78393071237092e-05,
                         'alpha_IC_8': -2.1170574016787528e-05, 'alpha_IC_9': 1.4667963623827045e-05,
                         'alpha_IH_0': -0.0007901075540167841, 'alpha_IH_1': -9.32921223684161e-05,
                         'alpha_IH_2': 0.0007197375713837021, 'alpha_IH_3': 0.0010810804900381772,
                         'alpha_IH_4': 0.0011571035178044413, 'alpha_IH_5': 0.0016342802164722393,
                         'alpha_IH_6': 0.002298359335586457, 'alpha_IH_7': 0.002116136854678609,
                         'alpha_IH_8': 0.0015997935516114292, 'alpha_IH_9': 0.0011529891801393111,
                         'ofi_0': 3.8366326574244033e-08, 'ofi_1': -9.419169206915914e-07,
                         'ofi_2': -1.0208887025043458e-06, 'ofi_3': -9.587240020442793e-07,
                         'ofi_4': -2.1085927316684547e-06, 'ofi_5': -2.2729185012424293e-06,
                         'ofi_6': -2.728001495761668e-06, 'ofi_7': -5.660944705489547e-07,
                         'ofi_8': 3.3006445638710634e-07, 'ofi_9': 6.1804018434382e-07, 'askt_0': 2.532808143720858e-05,
                         'askt_1': 2.6562162308257347e-05, 'askt_2': 2.1353025969545504e-05,
                         'askt_3': 2.1834578557595622e-05, 'askt_4': 2.5910457937628526e-05,
                         'askt_5': 2.1873803617391875e-05, 'askt_6': 2.4973089973261456e-05,
                         'askt_7': 2.1512473826174507e-05, 'askt_8': 1.0356702417326083e-05,
                         'askt_9': 8.506926423517349e-06, 'bidt_0': -1.6789411476260396e-07,
                         'bidt_1': -4.935084889914419e-06, 'bidt_2': -5.194225959553405e-06,
                         'bidt_3': -4.785601155810321e-06, 'bidt_4': -8.033784920058928e-06,
                         'bidt_5': -7.4028098321901095e-06, 'bidt_6': -4.515269281456326e-06,
                         'bidt_7': -5.642265465412286e-06, 'bidt_8': -5.2149934095414e-06,
                         'bidt_9': -1.2606654973541123e-05},
              '600753': {'SecuCode': '600753.SH', 'Interval': 20, 'Intercept': -0.023872450685364217,
                         'alpha_2_0': -4.1773510764680274e-05, 'alpha_2_1': -1.776849592210068e-05,
                         'alpha_2_2': -5.637278659153662e-06, 'alpha_2_3': -4.969306774342408e-06,
                         'alpha_2_4': -1.3665511269991754e-06, 'alpha_2_5': 1.9372247101146592e-07,
                         'alpha_2_6': 5.060275855790979e-06, 'alpha_2_7': 4.016019268473063e-06,
                         'alpha_2_8': 4.159310112861992e-06, 'alpha_2_9': 5.8639016281040405e-06,
                         'alpha_2_10': 4.085681324888899e-06, 'alpha_2_11': 3.6642106835548226e-06,
                         'alpha_2_12': 4.540298983302422e-06, 'alpha_2_13': 9.613740333400333e-07,
                         'alpha_2_14': 3.791208875867404e-06, 'alpha_2_15': 7.409017440553636e-06,
                         'alpha_2_16': 4.881862901748552e-06, 'alpha_2_17': 4.1559127301387835e-06,
                         'alpha_2_18': 1.774463181324682e-06, 'alpha_2_19': -3.2283372659390187e-08,
                         'alpha_3_0': 4.2540063434533155e-05, 'alpha_3_1': 1.7063550187906863e-05,
                         'alpha_3_2': 4.851403721280761e-06, 'alpha_3_3': 4.244046177202512e-06,
                         'alpha_3_4': 7.350791881414944e-07, 'alpha_3_5': -8.565640217627842e-07,
                         'alpha_3_6': -5.6118840883316205e-06, 'alpha_3_7': -4.37615595710456e-06,
                         'alpha_3_8': -3.7735699521287634e-06, 'alpha_3_9': -6.019998706150354e-06,
                         'alpha_3_10': -4.431824534210466e-06, 'alpha_3_11': -4.069654026777675e-06,
                         'alpha_3_12': -4.769759118101893e-06, 'alpha_3_13': -8.688646493865102e-07,
                         'alpha_3_14': -3.1102319504721213e-06, 'alpha_3_15': -6.716180748182601e-06,
                         'alpha_3_16': -4.6130198258004546e-06, 'alpha_3_17': -3.777069095563045e-06,
                         'alpha_3_18': -1.2809513482950618e-06, 'alpha_3_19': 1.0126471725258352e-06,
                         'alpha_spread_5_0': -0.09899211502419289, 'alpha_spread_5_1': 0.006540450769445566,
                         'alpha_spread_5_2': 0.00808552708657865, 'alpha_spread_5_3': 0.0017813886778892214,
                         'alpha_spread_5_4': -0.0003449448288514793, 'alpha_spread_5_5': -0.021747209663071598,
                         'alpha_spread_5_6': 0.009397489984928238, 'alpha_spread_5_7': 0.002156542671523532,
                         'alpha_spread_5_8': 0.0052732643705858916, 'alpha_spread_5_9': 0.01026274154960929,
                         'alpha_spread_6_0': 0.501831325936598, 'alpha_spread_6_1': -0.22462366267780792,
                         'alpha_spread_6_2': -0.03049779991244645, 'alpha_spread_6_3': 0.00016531983383635026,
                         'alpha_spread_6_4': 0.019582266906059118, 'alpha_spread_6_5': -0.009512269515867887,
                         'alpha_spread_6_6': 0.008215443701755884, 'alpha_spread_6_7': -0.001426375351563698,
                         'alpha_spread_6_8': 0.005962933057679865, 'alpha_spread_6_9': 0.02227421069153327,
                         'alpha_ret_0': 0.01029194099829378, 'alpha_ret_1': 0.005968226168821073,
                         'alpha_ret_2': -0.0021111868276987877, 'alpha_ret_3': -0.002302684487847215,
                         'alpha_ret_4': -0.001969230369582506, 'alpha_ret_5': 0.02144132057343176,
                         'alpha_ret_6': 0.011916895323386903, 'alpha_ret_7': 0.01325466838421476,
                         'alpha_ret_8': 0.011429959452606126, 'alpha_ret_9': 0.0005787921076888422,
                         'alpha_IF_0': 0.0015621770397879337, 'alpha_IF_1': 0.0023987204595216256,
                         'alpha_IF_2': 0.005183907895767395, 'alpha_IF_3': 0.008359017833250468,
                         'alpha_IF_4': 0.011147780370929656, 'alpha_IF_5': 0.011782797274035415,
                         'alpha_IF_6': 0.011792818012991644, 'alpha_IF_7': 0.010184623554658045,
                         'alpha_IF_8': 0.0083568056249717, 'alpha_IF_9': 0.005694908716412899,
                         'alpha_IC_0': -0.001173946899693744, 'alpha_IC_1': -0.0007775512842133074,
                         'alpha_IC_2': -0.0015091558311989834, 'alpha_IC_3': -0.0025985580657380282,
                         'alpha_IC_4': -0.0035813370791907277, 'alpha_IC_5': -0.0033779920183355516,
                         'alpha_IC_6': -0.0037550081928116185, 'alpha_IC_7': -0.0035323459792286093,
                         'alpha_IC_8': -0.003521196524279044, 'alpha_IC_9': -0.0030641400175788758,
                         'alpha_IH_0': 0.0001621173311877128, 'alpha_IH_1': -0.001982615158610694,
                         'alpha_IH_2': -0.004716986237726109, 'alpha_IH_3': -0.007233377773545575,
                         'alpha_IH_4': -0.0093918196699225, 'alpha_IH_5': -0.01084275633512052,
                         'alpha_IH_6': -0.01005526392317023, 'alpha_IH_7': -0.008034862816036095,
                         'alpha_IH_8': -0.00523347800250885, 'alpha_IH_9': -0.0021301137073157328,
                         'ofi_0': 6.6708050565155604e-06, 'ofi_1': 2.6007970799502382e-06,
                         'ofi_2': 3.0044537109940213e-06, 'ofi_3': 9.141355089491275e-07,
                         'ofi_4': -3.833239132326752e-06, 'ofi_5': -1.424092629882088e-06,
                         'ofi_6': -2.4093078582582433e-06, 'ofi_7': -3.384444345887671e-06,
                         'ofi_8': -1.8794755758586851e-06, 'ofi_9': -2.2913845067584372e-06,
                         'askt_0': 1.3486457117157577e-06, 'askt_1': 1.3828546422779686e-06,
                         'askt_2': 1.366045833606512e-06, 'askt_3': 1.1360845021492616e-08,
                         'askt_4': 1.0316936835763548e-05, 'askt_5': 1.3323468212164597e-05,
                         'askt_6': 1.046768458398275e-05, 'askt_7': 1.139051539180366e-05,
                         'askt_8': 1.7590351737782827e-05, 'askt_9': 1.140742880993001e-05,
                         'bidt_0': -7.361424913266237e-06, 'bidt_1': -9.082695543037725e-06,
                         'bidt_2': -7.647501652868278e-06, 'bidt_3': -4.177160728296506e-06,
                         'bidt_4': -3.7011362127506348e-06, 'bidt_5': -4.064884222761152e-06,
                         'bidt_6': -2.310794614322309e-06, 'bidt_7': -3.304148282247508e-06,
                         'bidt_8': -3.867298371176858e-06, 'bidt_9': -2.772206915829886e-06},
              '600696': {'SecuCode': '600696.SH', 'Interval': 20, 'Intercept': -0.0054851175247010294,
                         'alpha_2_0': -4.699264618290771e-05, 'alpha_2_1': -3.815445325947019e-07,
                         'alpha_2_2': -2.296346416855055e-07, 'alpha_2_3': -4.735328984919879e-06,
                         'alpha_2_4': -1.3047201539287809e-06, 'alpha_2_5': 2.74682329164904e-06,
                         'alpha_2_6': 2.4803014357702596e-06, 'alpha_2_7': 2.029969725971098e-06,
                         'alpha_2_8': 2.3621819967179074e-06, 'alpha_2_9': 4.433198383914705e-06,
                         'alpha_2_10': 7.109146227861846e-06, 'alpha_2_11': 7.500616440031489e-06,
                         'alpha_2_12': 9.718526951727081e-06, 'alpha_2_13': 1.1563010679658215e-05,
                         'alpha_2_14': 1.2473868125316707e-05, 'alpha_2_15': 1.171235495089195e-05,
                         'alpha_2_16': 9.504339560684733e-06, 'alpha_2_17': 1.3094796493517466e-05,
                         'alpha_2_18': 1.0788154941341288e-05, 'alpha_2_19': 1.968494923044822e-05,
                         'alpha_3_0': 4.769666350311429e-05, 'alpha_3_1': 5.528626802762555e-07,
                         'alpha_3_2': 2.410660471269722e-07, 'alpha_3_3': 5.00596871799123e-06,
                         'alpha_3_4': 1.4860117955583704e-06, 'alpha_3_5': -2.5872631423185053e-06,
                         'alpha_3_6': -2.2576445539108238e-06, 'alpha_3_7': -1.7983010769987335e-06,
                         'alpha_3_8': -2.4191488788483894e-06, 'alpha_3_9': -3.982009827998875e-06,
                         'alpha_3_10': -6.934872022172351e-06, 'alpha_3_11': -7.348732878353225e-06,
                         'alpha_3_12': -9.452020207218672e-06, 'alpha_3_13': -1.1482174863074056e-05,
                         'alpha_3_14': -1.2372338406282507e-05, 'alpha_3_15': -1.1373618987047785e-05,
                         'alpha_3_16': -8.900621884849597e-06, 'alpha_3_17': -1.2853333085274439e-05,
                         'alpha_3_18': -1.0925486484800843e-05, 'alpha_3_19': -1.986698588268671e-05,
                         'alpha_spread_5_0': -0.10893905568731893, 'alpha_spread_5_1': 0.0006032501974731078,
                         'alpha_spread_5_2': -0.015722355018069997, 'alpha_spread_5_3': 0.0034531381585638046,
                         'alpha_spread_5_4': 0.016575955163561796, 'alpha_spread_5_5': -0.0023818436031112756,
                         'alpha_spread_5_6': -0.011055152479993592, 'alpha_spread_5_7': 0.015541579152086942,
                         'alpha_spread_5_8': 0.0030657829456178587, 'alpha_spread_5_9': 0.0021783634986820904,
                         'alpha_spread_6_0': 0.194004758368908, 'alpha_spread_6_1': -0.08918233247844538,
                         'alpha_spread_6_2': -0.013028354056510967, 'alpha_spread_6_3': -0.014520462429918217,
                         'alpha_spread_6_4': 0.01394194776841318, 'alpha_spread_6_5': 0.0005470158441865411,
                         'alpha_spread_6_6': 0.00873841181663427, 'alpha_spread_6_7': -0.01858822586917619,
                         'alpha_spread_6_8': -0.02109279927250053, 'alpha_spread_6_9': 0.05758162324767893,
                         'alpha_ret_0': 0.08459396561793157, 'alpha_ret_1': 0.06328725577635377,
                         'alpha_ret_2': 0.054124296817568376, 'alpha_ret_3': -0.012468136917545114,
                         'alpha_ret_4': -0.048596795276350344, 'alpha_ret_5': -0.05593389984892061,
                         'alpha_ret_6': -0.023770709710603796, 'alpha_ret_7': -0.022374325263060074,
                         'alpha_ret_8': -0.04252608613573265, 'alpha_ret_9': 0.005015513916639398,
                         'alpha_IF_0': 0.001276937012485727, 'alpha_IF_1': 0.0013388357061766966,
                         'alpha_IF_2': -0.000709980184540263, 'alpha_IF_3': -0.0005349909357672405,
                         'alpha_IF_4': 0.0007462566963333284, 'alpha_IF_5': -0.00030656235201494765,
                         'alpha_IF_6': -0.001394728447342343, 'alpha_IF_7': -0.0006030169275958983,
                         'alpha_IF_8': -0.0013616424156287325, 'alpha_IF_9': -0.0005545634183679815,
                         'alpha_IC_0': -0.0006669408686711933, 'alpha_IC_1': 0.0002521322206033875,
                         'alpha_IC_2': 0.0006732855305534973, 'alpha_IC_3': 0.0004814368352844358,
                         'alpha_IC_4': -1.278476660111083e-05, 'alpha_IC_5': 0.0004846766821438311,
                         'alpha_IC_6': 0.0006613584411239362, 'alpha_IC_7': 0.0007274249988279013,
                         'alpha_IC_8': 0.0013976983914258366, 'alpha_IC_9': 0.0010603023158038951,
                         'alpha_IH_0': -0.0005120730948249956, 'alpha_IH_1': -0.0025637172179268203,
                         'alpha_IH_2': -0.00033535966001217195, 'alpha_IH_3': -0.00015405687943121138,
                         'alpha_IH_4': -0.0010504065393196912, 'alpha_IH_5': -0.0004948432507728525,
                         'alpha_IH_6': 0.0007965342883366932, 'alpha_IH_7': -0.0005500822907672836,
                         'alpha_IH_8': -0.0008217263359337574, 'alpha_IH_9': -0.0013489672857675957,
                         'ofi_0': 4.068628281116433e-05, 'ofi_1': 1.5182994847514034e-05,
                         'ofi_2': 1.7912648404772732e-05, 'ofi_3': 1.4979795364353795e-05,
                         'ofi_4': 1.2973988938704064e-05, 'ofi_5': 9.465248855252565e-06,
                         'ofi_6': 7.018194436844049e-07, 'ofi_7': 1.701409696243577e-07,
                         'ofi_8': -9.806367695590899e-07, 'ofi_9': -1.8376552716992446e-06,
                         'askt_0': -2.22386077704988e-05, 'askt_1': -3.120783651519961e-05,
                         'askt_2': -2.004924979570698e-05, 'askt_3': -3.4772827560117554e-06,
                         'askt_4': -6.857027263276493e-06, 'askt_5': -3.679021232085125e-06,
                         'askt_6': 4.97086422292877e-06, 'askt_7': 7.308849166875598e-06,
                         'askt_8': 1.2053127684625646e-05, 'askt_9': 5.741154992280784e-06,
                         'bidt_0': 4.918144428998662e-07, 'bidt_1': -1.3363817613097937e-06,
                         'bidt_2': 8.38387199584835e-08, 'bidt_3': 3.6959750218758395e-06,
                         'bidt_4': 2.2009752770612182e-06, 'bidt_5': 1.1670273381397552e-06,
                         'bidt_6': 6.201171900906448e-07, 'bidt_7': 2.2530226154397984e-06,
                         'bidt_8': 2.4098954168605684e-06, 'bidt_9': 1.1487211297840105e-06}}

    # data = AddT0Factor(body=factor)
    # print(data)














    print(time.time()-t1)